﻿USE teachcloud_report_db;
-- ----------------------------
-- Table structure for basic_attachment
-- ----------------------------
DROP TABLE IF EXISTS `basic_attachment`;
CREATE TABLE `basic_attachment` (
                                    `id` bigint NOT NULL COMMENT '主键',
                                    `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                    `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                    `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '文件名',
                                    `type` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '文件类型',
                                    `size` int NOT NULL COMMENT '单位（KB）',
                                    `md5` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '文件md5值',
                                    `path` varchar(2000) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '存储路径',
                                    `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                    `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                    `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                    `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                    `obj_id` bigint DEFAULT NULL COMMENT '关联业务id',
                                    PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='所有附件记录表';

-- ----------------------------
-- Table structure for basic_campus
-- ----------------------------
DROP TABLE IF EXISTS `basic_campus`;
CREATE TABLE `basic_campus` (
                                `id` bigint NOT NULL COMMENT '校区id',
                                `school_id` bigint NOT NULL COMMENT '学校id',
                                `campus_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '校区名称',
                                `campus_code` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '校区编码',
                                `print_house_id` bigint DEFAULT NULL COMMENT '印刷室id',
                                `enable` tinyint DEFAULT '1' COMMENT '是否可用',
                                `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                PRIMARY KEY (`id`) USING BTREE,
                                UNIQUE KEY `campus_schoolId_code_idx` (`school_id`,`campus_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='基础校区表';

-- ----------------------------
-- Table structure for basic_card_rule
-- ----------------------------
DROP TABLE IF EXISTS `basic_card_rule`;
CREATE TABLE `basic_card_rule` (
                                   `id` bigint NOT NULL COMMENT '主键',
                                   `school_id` bigint NOT NULL COMMENT '学校id',
                                   `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                   `name` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '题卡规则名称',
                                   `exam_number_style` varchar(5) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'PRINT-印刷条码，PASTE-粘贴条码，FILL-卡号填涂',
                                   `exam_number_digit` int DEFAULT NULL COMMENT '考号位数',
                                   `paper_type` varchar(5) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'PRINT-印刷条码，FILL-卡号填涂',
                                   `exam_absent` tinyint NOT NULL COMMENT '0-禁用，1-启用',
                                   `write_sign` tinyint NOT NULL COMMENT '0-禁用，1-启用',
                                   `discipline` tinyint(1) DEFAULT NULL COMMENT '违纪填涂（1：是，0：否）',
                                   `required_fields` text CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '必选字段',
                                   `extend_fields` text CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '扩展字段',
                                   `title_rule` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '题卡标题规则',
                                   `attention` text CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '注意事项',
                                   `objective_attention` text CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '客观题注意事项',
                                   `subjective_attention` text CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '主观题注意事项',
                                   `enable` tinyint NOT NULL COMMENT '0-禁用，1-启用',
                                   `remark` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '备注',
                                   `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                   `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                   `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                   `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                   `fill_number` tinyint DEFAULT NULL COMMENT '卡号填涂位数',
                                   PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='题卡规则';

-- ----------------------------
-- Table structure for basic_clazz
-- ----------------------------
DROP TABLE IF EXISTS `basic_clazz`;
CREATE TABLE `basic_clazz` (
                               `id` bigint NOT NULL,
                               `school_id` bigint NOT NULL COMMENT '学校id',
                               `major_id` bigint NOT NULL COMMENT '专业id',
                               `clazz_code` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '班级编号',
                               `short_code` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '简码',
                               `clazz_name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '班级名称',
                               `enable` tinyint(1) DEFAULT NULL COMMENT '是否可用',
                               `org_id` bigint DEFAULT NULL COMMENT '权限机构id',
                               `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                               `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                               `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                               `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                               PRIMARY KEY (`id`) USING BTREE,
                               UNIQUE KEY `clazz_schoolId_name_idx` (`school_id`,`clazz_name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='基础班级表';

-- ----------------------------
-- Table structure for basic_college
-- ----------------------------
DROP TABLE IF EXISTS `basic_college`;
CREATE TABLE `basic_college` (
                                 `id` bigint NOT NULL,
                                 `school_id` bigint NOT NULL,
                                 `college_name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '学院名称',
                                 `org_id` bigint NOT NULL COMMENT '数据权限机构id',
                                 `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                 `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                 `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                 `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                 PRIMARY KEY (`id`),
                                 UNIQUE KEY `college_schoolId_name_idx` (`school_id`,`college_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学生学院表';

-- ----------------------------
-- Table structure for basic_course
-- ----------------------------
DROP TABLE IF EXISTS `basic_course`;
CREATE TABLE `basic_course` (
                                `id` bigint NOT NULL COMMENT '主键',
                                `school_id` bigint NOT NULL COMMENT '学校id',
                                `org_id` bigint NOT NULL COMMENT '机构id',
                                `code` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程编码',
                                `short_code` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '简码',
                                `name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程名称',
                                `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                `update_id` bigint DEFAULT NULL COMMENT '修改人',
                                `update_time` bigint DEFAULT NULL COMMENT '修改时间',
                                `teaching_room_id` bigint DEFAULT NULL COMMENT '教研室id',
                                `enable` tinyint DEFAULT NULL,
                                `historic_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '历史课程名称',
                                PRIMARY KEY (`id`) USING BTREE,
                                UNIQUE KEY `course_schoolId_code_idx` (`school_id`,`code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='课程表';

-- ----------------------------
-- Table structure for basic_exam
-- ----------------------------
DROP TABLE IF EXISTS `basic_exam`;
CREATE TABLE `basic_exam` (
                              `id` bigint NOT NULL,
                              `school_id` bigint NOT NULL,
                              `org_id` bigint NOT NULL,
                              `semester_id` bigint DEFAULT NULL COMMENT '学期ID',
                              `short_code` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '简码',
                              `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考试名称',
                              `category` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考试类型（ONLINE：线上，OFFLINE：线下）',
                              `exam_model` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '业务模式（MODEL1：电子交卷环节需要提交考务数据，MODEL2：电子交卷环节不需要提交考务数据，只输入印刷份数即可，MODEL3：电子交卷环节不需要提交考务数据）',
                              `review` tinyint(1) DEFAULT NULL COMMENT '是否启用入库审核：0-禁用，1-启用',
                              `print_method` varchar(6) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT 'AUTO-自动，MANUAL-手动',
                              `enable` tinyint(1) NOT NULL DEFAULT '1' COMMENT '1启用/0禁用',
                              `in_used` tinyint(1) NOT NULL DEFAULT '1' COMMENT '1是/0否',
                              `create_id` bigint DEFAULT NULL,
                              `create_time` bigint DEFAULT NULL,
                              `update_id` bigint DEFAULT NULL,
                              `update_time` bigint DEFAULT NULL,
                              PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考试表';

-- ----------------------------
-- Table structure for basic_exam_rule
-- ----------------------------
DROP TABLE IF EXISTS `basic_exam_rule`;
CREATE TABLE `basic_exam_rule` (
                                   `id` bigint NOT NULL COMMENT '主键',
                                   `school_id` bigint NOT NULL COMMENT '学校id',
                                   `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                   `required_fields` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '必选字段',
                                   `extend_fields` text CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '扩展字段',
                                   `exam_number_digit` int DEFAULT NULL COMMENT '考号位数',
                                   `sign_scope` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '签到表字段可选范围',
                                   `package_scope` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '卷袋贴字段可选范围',
                                   `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                   `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                   `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                   `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                   PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考务规则';

-- ----------------------------
-- Table structure for basic_major
-- ----------------------------
DROP TABLE IF EXISTS `basic_major`;
CREATE TABLE `basic_major` (
                               `id` bigint NOT NULL COMMENT '主键',
                               `school_id` bigint NOT NULL COMMENT '学校id',
                               `org_id` bigint NOT NULL COMMENT '机构id',
                               `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '专业名称',
                               `code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '专业编码',
                               `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                               `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                               `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                               `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                               `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                               `belong_org_id` bigint NOT NULL COMMENT '所属机构id',
                               PRIMARY KEY (`id`) USING BTREE,
                               UNIQUE KEY `major_schoolId_name_idx` (`school_id`,`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='专业字典表';

-- ----------------------------
-- Table structure for basic_message
-- ----------------------------
DROP TABLE IF EXISTS `basic_message`;
CREATE TABLE `basic_message` (
                                 `id` bigint NOT NULL COMMENT '主键',
                                 `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                 `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                 `user_id` bigint NOT NULL COMMENT '消息接收人用户',
                                 `user_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '用户名称',
                                 `mobile_number` varchar(11) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '电话号码',
                                 `paper_number` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷编号',
                                 `course_code` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程代码',
                                 `message_type` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '消息类型',
                                 `business_operate` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '业务操作',
                                 `business_id` bigint DEFAULT NULL COMMENT '业务id',
                                 `template_code` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '消息模板代码',
                                 `variable_params` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '变量参数内容',
                                 `template_content` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '模板内容',
                                 `send_status` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '消息发送状态',
                                 `send_result` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '消息发送结果',
                                 `remark` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '备注',
                                 `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                 `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                 `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                 `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                 `resend_count` int DEFAULT NULL COMMENT '重试次数',
                                 PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for basic_operation_log
-- ----------------------------
DROP TABLE IF EXISTS `basic_operation_log`;
CREATE TABLE `basic_operation_log` (
                                       `id` bigint NOT NULL COMMENT 'id',
                                       `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                       `org_id` bigint DEFAULT NULL COMMENT '数据权限id',
                                       `detail` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '日志详情',
                                       `level` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '日志等级（PRIMARY("一级日志：敏感信息"),SECONDARY("二级日志：重要信息"),TERTIARY("三级日志：次要信息"),QUATERNARY("四级日志：普通信息")）',
                                       `customized_operation_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '自定义记录日志操作类型（LOGIN("用户登录"),LOGOUT("用户登出"),ADD("新增"),DELETE("删除"),UPDATE("修改"),IMPORT("导入"),EXPORT("导出"),UN_KNOW("未知")）',
                                       `operation_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '操作类型（UN_KNOW("未知"),SELECT("查询"),EDIT("新增或更新"),DELETE("删除")）',
                                       `operation_unit` varchar(128) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '操作对象（略）',
                                       `system_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '日志系统类型',
                                       `url` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '请求地址url',
                                       `clazz_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '类名称',
                                       `method` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '方法名称',
                                       `args` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '参数',
                                       `run_time` bigint DEFAULT NULL COMMENT '方法运行时间',
                                       `run_status` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '方法运行状态',
                                       `return_value` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '方法返回值',
                                       `user_id` bigint NOT NULL COMMENT '用户对象id',
                                       `user_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '用户名称',
                                       `ip` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'ip地址',
                                       `create_time` bigint DEFAULT NULL COMMENT '日志记录时间',
                                       PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='基础日志记录表';

-- ----------------------------
-- Table structure for basic_print_config
-- ----------------------------
DROP TABLE IF EXISTS `basic_print_config`;
CREATE TABLE `basic_print_config` (
                                      `id` bigint NOT NULL,
                                      `school_id` bigint NOT NULL COMMENT '学校ID',
                                      `org_id` bigint NOT NULL COMMENT '机构id',
                                      `exam_id` bigint DEFAULT NULL COMMENT '考试ID',
                                      `enable` tinyint(1) NOT NULL DEFAULT '1' COMMENT '1启用/0禁用',
                                      `card_rule_id` bigint DEFAULT NULL COMMENT '题卡规则（-1代表通卡）',
                                      `print_content` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷、题卡',
                                      `backup_method` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷题卡备份方式（ROOM按考场）',
                                      `backup_count` int DEFAULT NULL COMMENT '试卷题卡备份数量',
                                      `draw_rule` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '抽卷规则（ONE只抽一次，CIRCLE循环抽取）',
                                      `variable_content` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '变量印品参数json',
                                      `ordinary_content` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '普通印品参数json',
                                      `create_id` bigint DEFAULT NULL,
                                      `create_time` bigint DEFAULT NULL,
                                      `update_id` bigint DEFAULT NULL,
                                      `update_time` bigint DEFAULT NULL,
                                      `review` tinyint DEFAULT NULL COMMENT '是否启用入库审核：0-禁用，1-启用',
                                      `print_method` varchar(6) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT 'AUTO-自动，MANUAL-手动',
                                      PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='印品配置表';

-- ----------------------------
-- Table structure for basic_role_data_permission
-- ----------------------------
DROP TABLE IF EXISTS `basic_role_data_permission`;
CREATE TABLE `basic_role_data_permission` (
                                              `id` bigint NOT NULL COMMENT 'id',
                                              `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                              `role_id` bigint NOT NULL COMMENT '角色id',
                                              `privilege_id` bigint NOT NULL COMMENT '权限id',
                                              `data_permission_type` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '数据权限类型',
                                              `org_scope` varchar(45) DEFAULT NULL COMMENT '数据权限机构权限组',
                                              `org_id` bigint DEFAULT NULL COMMENT '创建人机构id',
                                              `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                              `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                              `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                              `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                              PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='角色数据权限表';

-- ----------------------------
-- Table structure for basic_school
-- ----------------------------
DROP TABLE IF EXISTS `basic_school`;
CREATE TABLE `basic_school` (
                                `id` bigint NOT NULL COMMENT '主键',
                                `code` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '学校编码',
                                `domain_name` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '域名',
                                `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学校名称',
                                `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
                                `access_key` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '访问key',
                                `access_secret` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '访问秘钥',
                                `remark` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '备注',
                                `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                `logo` varchar(2000) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '学校logo',
                                PRIMARY KEY (`id`) USING BTREE,
                                UNIQUE KEY `code` (`code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校表';

-- ----------------------------
-- Table structure for basic_semester
-- ----------------------------
DROP TABLE IF EXISTS `basic_semester`;
CREATE TABLE `basic_semester` (
                                  `id` bigint NOT NULL COMMENT '主键',
                                  `school_id` bigint NOT NULL COMMENT '学校id',
                                  `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '学期名称',
                                  `code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学期编码',
                                  `start_time` bigint DEFAULT NULL COMMENT '开始日期',
                                  `end_time` bigint DEFAULT NULL COMMENT '结束日期',
                                  `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                  `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                  `in_used` tinyint(1) DEFAULT NULL COMMENT '是否当前使用学期',
                                  PRIMARY KEY (`id`) USING BTREE,
                                  UNIQUE KEY `semester_schoolId_name_idx` (`school_id`,`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学期字典表';

-- ----------------------------
-- Table structure for basic_student
-- ----------------------------
DROP TABLE IF EXISTS `basic_student`;
CREATE TABLE `basic_student` (
                                 `id` bigint NOT NULL COMMENT '学生id',
                                 `school_id` bigint NOT NULL COMMENT '学校id',
                                 `student_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '学生姓名',
                                 `student_code` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '学生编号',
                                 `phone_number` varchar(11) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '电话号码',
                                 `belong_org_id` bigint DEFAULT NULL COMMENT '所属院系',
                                 `major_id` bigint DEFAULT NULL COMMENT '专业id',
                                 `clazz_id` bigint DEFAULT NULL COMMENT '班级主键',
                                 `enable` tinyint DEFAULT '1' COMMENT '可用状态（1：可用，0：不可用）',
                                 `org_id` bigint DEFAULT NULL COMMENT '可操作人机构id',
                                 `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                 `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                 `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                 `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                 PRIMARY KEY (`id`) USING BTREE,
                                 UNIQUE KEY `student_schoolId_code_orgId_idx` (`school_id`,`student_code`,`belong_org_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校id';

-- ----------------------------
-- Table structure for basic_template
-- ----------------------------
DROP TABLE IF EXISTS `basic_template`;
CREATE TABLE `basic_template` (
                                  `id` bigint NOT NULL COMMENT '主键',
                                  `school_id` bigint NOT NULL COMMENT '学校id',
                                  `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                  `name` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '模板名称',
                                  `classify` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT 'template_type值为VARIABLE、ORDINARY时，不为空。\n  SIGN-签到表，PACKAGE-卷袋贴，CHECK_IN-登记表',
                                  `display_range` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '卷袋贴、签到表数据范围',
                                  `preview_path` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '预览地址',
                                  `attachment_id` bigint DEFAULT NULL COMMENT '模板附件ID（保存到附件表ID）',
                                  `enable` tinyint NOT NULL COMMENT '0-禁用，1-启用',
                                  `remark` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '备注',
                                  `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                  `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='通用模板';

-- ----------------------------
-- Table structure for basic_template_org
-- ----------------------------
DROP TABLE IF EXISTS `basic_template_org`;
CREATE TABLE `basic_template_org` (
                                      `id` bigint NOT NULL COMMENT '主键',
                                      `school_id` bigint NOT NULL COMMENT '学校id',
                                      `type` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '模板类型：GENERIC-通卡模板，VARIABLE-变量印品模板，ORDINARY-普通印品模板，CARD_RULE-题卡规则，PRINT_CONFIG-印品配置',
                                      `rule_id` bigint NOT NULL COMMENT '通卡模板ID',
                                      `org_id` bigint NOT NULL COMMENT '组织机构ID',
                                      `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                      `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                      `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                      `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                      PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='适用学院（题卡规则、模板适用学院）';

-- ----------------------------
-- Table structure for basic_user_course
-- ----------------------------
DROP TABLE IF EXISTS `basic_user_course`;
CREATE TABLE `basic_user_course` (
                                     `id` bigint NOT NULL COMMENT '主键',
                                     `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                     `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                     `user_id` bigint DEFAULT NULL COMMENT '用户ID',
                                     `course_id` bigint DEFAULT NULL COMMENT '课程ID',
                                     `clazz_id` bigint DEFAULT NULL COMMENT '授课班级',
                                     `enable` tinyint(1) DEFAULT NULL COMMENT '是否启用？1-是 ；0-否',
                                     `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                     `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                     `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                     `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                     PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='用户和课程关联表';

-- ----------------------------
-- Table structure for basic_verify_code
-- ----------------------------
DROP TABLE IF EXISTS `basic_verify_code`;
CREATE TABLE `basic_verify_code` (
                                     `id` bigint NOT NULL COMMENT '主键',
                                     `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                     `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                     `user_id` bigint NOT NULL COMMENT '用户ID',
                                     `mobile_number` varchar(11) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '手机号',
                                     `expire_time` bigint NOT NULL COMMENT '到期时间',
                                     `valid_period` int NOT NULL COMMENT '单位（分）',
                                     `verify_code` varchar(4) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '4位数字',
                                     `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                     `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                     `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                     `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                     PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='短信验证码记录表';

-- ----------------------------
-- Table structure for client_print_data
-- ----------------------------
DROP TABLE IF EXISTS `client_print_data`;
CREATE TABLE `client_print_data` (
                                     `id` bigint NOT NULL COMMENT '主键',
                                     `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                     `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                     `exam_detail_id` bigint DEFAULT NULL COMMENT '考场ID',
                                     `machine_code` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '机器唯一码',
                                     `pages_a4` int DEFAULT NULL COMMENT 'A4页数量',
                                     `paper_pages` int DEFAULT NULL COMMENT '试卷数量',
                                     `card_pages` int DEFAULT NULL COMMENT '题卡数量',
                                     `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                     `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                     `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                     `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                     PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='各机器打印数量';

-- ----------------------------
-- Table structure for client_status
-- ----------------------------
DROP TABLE IF EXISTS `client_status`;
CREATE TABLE `client_status` (
                                 `id` bigint NOT NULL AUTO_INCREMENT COMMENT '主键',
                                 `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                 `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                 `machine_code` varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL COMMENT '机器唯一码',
                                 `exam_detail_id` bigint DEFAULT NULL COMMENT '考场ID',
                                 `print_plan_id` bigint DEFAULT NULL COMMENT '印刷计划ID',
                                 `course_code` varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL COMMENT '课程代码',
                                 `course_name` varchar(200) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL COMMENT '课程名称',
                                 `paper_number` varchar(50) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL COMMENT '试卷编号',
                                 `is_try` tinyint DEFAULT NULL COMMENT '是否打样：true-是，false-否',
                                 `try_time` bigint DEFAULT NULL COMMENT '打样时间',
                                 `is_pass` tinyint DEFAULT NULL COMMENT '是否合格：true-合格，false-不合格',
                                 `is_download` tinyint DEFAULT NULL COMMENT '是否缓存：true-是，false-否',
                                 `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                 `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                 `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                 `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                 PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='机器打样记录';

-- ----------------------------
-- Table structure for cloud_user_push_status
-- ----------------------------
DROP TABLE IF EXISTS `cloud_user_push_status`;
CREATE TABLE `cloud_user_push_status` (
                                          `id` bigint NOT NULL,
                                          `school_id` bigint NOT NULL COMMENT '学校id',
                                          `user_id` bigint NOT NULL,
                                          `marker_status` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '评卷员推送状态(UserPushResultEnum):BIND_SUCCESS("绑定成功"),BIND_FAILED("绑定失败"),UNBIND_SUCCESS("解绑成功"),UNBIND_FAILED("解绑失败");',
                                          `marker_leader_status` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '科组长推送状态(UserPushResultEnum):BIND_SUCCESS("绑定成功"),BIND_FAILED("绑定失败"),UNBIND_SUCCESS("解绑成功"),UNBIND_FAILED("解绑失败");',
                                          `sync_status` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '同步状态(SyncStatusEnum)，ALREADY_PUSH("已经完成推送"),NEED_PUSH_AGAIN("需要重新推送");',
                                          `create_id` bigint DEFAULT NULL COMMENT '创建人\n',
                                          `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                          `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                          `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                          PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='云阅卷用户推送状态表';

-- ----------------------------
-- Table structure for exam_card
-- ----------------------------
DROP TABLE IF EXISTS `exam_card`;
CREATE TABLE `exam_card` (
                             `id` bigint NOT NULL COMMENT '主键',
                             `school_id` bigint NOT NULL COMMENT '学校id',
                             `org_id` bigint DEFAULT NULL COMMENT '机构id',
                             `course_code` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程编码',
                             `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程名称',
                             `title` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '标题',
                             `make_method` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '题卡制作方式：SELECT-选择已有题卡，SELF-自助创建，CUST-客户制卡',
                             `status` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT 'STAGE-暂存，SUBMIT-提交',
                             `create_id` bigint DEFAULT NULL COMMENT '创建人',
                             `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                             `update_id` bigint DEFAULT NULL COMMENT '更新人',
                             `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                             `type` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '题卡类型：GENERIC-通卡，CUSTOM-自定义',
                             `create_method` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '通卡创建方式（UPLOAD-上传，CUSTOMIZE-自定义）',
                             `attachment_id` bigint DEFAULT NULL COMMENT 'type=GENERIC时必传，上传附件ID',
                             `sync_status` tinyint(1) DEFAULT NULL COMMENT '是否同步成功：true-是， false-否',
                             `enable` tinyint(1) DEFAULT '1' COMMENT '1正常，0禁用',
                             `remark` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '备注',
                             `card_rule_id` bigint DEFAULT NULL COMMENT '题卡规则Id',
                             PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='题卡';

-- ----------------------------
-- Table structure for exam_card_detail
-- ----------------------------
DROP TABLE IF EXISTS `exam_card_detail`;
CREATE TABLE `exam_card_detail` (
                                    `id` bigint NOT NULL COMMENT '主键',
                                    `card_id` bigint NOT NULL COMMENT '题卡ID',
                                    `content` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '题卡工具制作题卡内容',
                                    `html_content` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT 'html格式内容',
                                    `attachment_id` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '备用题卡json',
                                    `cust_attachment_id` bigint DEFAULT NULL COMMENT '客服制卡上传附件ID',
                                    `jpg_attachment_info` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '题卡转换成的jpg文件信息',
                                    `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                    `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                    `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                    `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                    PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='题卡详情';

-- ----------------------------
-- Table structure for exam_detail
-- ----------------------------
DROP TABLE IF EXISTS `exam_detail`;
CREATE TABLE `exam_detail` (
                               `id` bigint NOT NULL COMMENT '主键',
                               `school_id` bigint NOT NULL COMMENT '学校id',
                               `org_id` bigint NOT NULL COMMENT '机构id',
                               `print_plan_id` bigint NOT NULL COMMENT '印刷计划ID',
                               `print_plan_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '印刷计划名称',
                               `exam_start_time` bigint NOT NULL COMMENT '考试开始日期',
                               `exam_end_time` bigint NOT NULL COMMENT '考试结束日期',
                               `exam_place` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考场',
                               `total_subjects` int DEFAULT NULL COMMENT '总科次：考场总科次',
                               `exam_room` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教室',
                               `print_progress` double DEFAULT NULL COMMENT '打印进度',
                               `print_user` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '打印员：一个考场只能被一个打印员认领',
                               `package_code` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '考场代码：卷袋贴、签到表上条码',
                               `paper_pages` int DEFAULT NULL COMMENT '试卷总计（张）',
                               `card_pages` int DEFAULT NULL COMMENT '题卡总计（张）',
                               `pages_a4` int DEFAULT NULL COMMENT 'A4印量小计（页）',
                               `status` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '状态：NEW: "新建",READY: "就绪",WAITING: "待印刷",PRINTING: "印刷中",FINISH: "已完成"',
                               `validate` tinyint(1) DEFAULT '0' COMMENT '是否校验：true-是，false-否',
                               `print_start_time` bigint DEFAULT NULL COMMENT '打印开始时间',
                               `print_end_time` bigint DEFAULT NULL COMMENT '打印完成时间',
                               `attachment_id` bigint DEFAULT NULL COMMENT '附件id',
                               `card_attachment_id` bigint DEFAULT NULL COMMENT '题卡合并A3文件附件ID',
                               `create_id` bigint DEFAULT NULL COMMENT '创建人',
                               `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                               `update_id` bigint DEFAULT NULL COMMENT '更新人',
                               `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                               `attachment_path` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '印品附件路径',
                               `exam_data_source` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '数据来源（EXAM_TASK：卷库查询生成，FILE_IMPORT：考务文件导入）',
                               `normal` tinyint DEFAULT '1' COMMENT '是否正常，true正常，false做废',
                               `print_house_id` bigint DEFAULT NULL COMMENT '印刷室ID',
                               `print_count` int DEFAULT NULL COMMENT '模式2，考生数量（打印数量）',
                               PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考务数据';

-- ----------------------------
-- Table structure for exam_detail_course
-- ----------------------------
DROP TABLE IF EXISTS `exam_detail_course`;
CREATE TABLE `exam_detail_course` (
                                      `id` bigint NOT NULL COMMENT '主键',
                                      `school_id` bigint NOT NULL COMMENT '学校id',
                                      `org_id` bigint NOT NULL COMMENT '机构id',
                                      `exam_detail_id` bigint NOT NULL COMMENT '考试明细id',
                                      `course_code` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程编码',
                                      `course_name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程名称',
                                      `paper_number` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '页数',
                                      `total_subjects` int DEFAULT NULL COMMENT '总科次：考场总科次',
                                      `paper_pages_a3` int DEFAULT NULL COMMENT '试卷单科次准印量A3（页）',
                                      `card_pages_a3` int DEFAULT NULL COMMENT '题卡单科次准印量A3（页）',
                                      `clazz_id` text CHARACTER SET utf8 COLLATE utf8_general_ci,
                                      `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                      `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                      `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                      `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                      `paper_type` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '当前试卷类型',
                                      `attachment_id` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '备用题卡json',
                                      `common_attachment_id` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '模式2下考生公共题卡json',
                                      `third_relate_id` bigint DEFAULT NULL COMMENT '云阅卷ID',
                                      `sync_status` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '同步状态',
                                      `sync_user_id` bigint DEFAULT NULL COMMENT '推送人',
                                      PRIMARY KEY (`id`) USING BTREE,
                                      KEY `detail_course_schoolId_idx` (`school_id`,`paper_number`,`paper_type`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考务数据（考场关联科目）';

-- ----------------------------
-- Table structure for exam_paper_group
-- ----------------------------
DROP TABLE IF EXISTS `exam_paper_group`;
CREATE TABLE `exam_paper_group` (
                                    `id` bigint NOT NULL COMMENT '分组id',
                                    `exam_paper_structure_id` bigint NOT NULL COMMENT '试卷结构id',
                                    `group_number` int NOT NULL COMMENT '分组序号',
                                    `double_rate` tinyint DEFAULT NULL COMMENT '双评比例（0关闭，1开启）',
                                    `arbitrate_threshold` int DEFAULT NULL COMMENT '仲裁阈值（开启双评必填）',
                                    `score_policy` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '合分策略 开启双评是必填 AVG("平均分", 1), MAX("最高分", 2), MIN("最低分", 3)',
                                    `trial_count` int DEFAULT NULL COMMENT '试评数量',
                                    `mark_mode` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '评卷模式 COMMON("普通"), TRACK("轨迹")',
                                    `question_info` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '题目信息',
                                    `picture_config` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '图片配置',
                                    `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                    `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                    `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                    `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                    PRIMARY KEY (`id`),
                                    UNIQUE KEY `exam_paper_group_unique` (`exam_paper_structure_id`,`group_number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='试卷分组表';

-- ----------------------------
-- Table structure for exam_paper_group_marker
-- ----------------------------
DROP TABLE IF EXISTS `exam_paper_group_marker`;
CREATE TABLE `exam_paper_group_marker` (
                                           `id` bigint NOT NULL COMMENT '评卷员-分组关系id',
                                           `group_id` bigint NOT NULL COMMENT '分组id',
                                           `marker_id` bigint NOT NULL COMMENT '评卷员id',
                                           `login_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '评卷员登录名',
                                           `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                           `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                           `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                           `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                           PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='评卷员-分组关系表';

-- ----------------------------
-- Table structure for exam_paper_structure
-- ----------------------------
DROP TABLE IF EXISTS `exam_paper_structure`;
CREATE TABLE `exam_paper_structure` (
                                        `id` bigint NOT NULL COMMENT '主键',
                                        `school_id` bigint DEFAULT NULL COMMENT '学校ID',
                                        `semester_id` bigint DEFAULT NULL COMMENT '学期ID',
                                        `semester_name` varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci DEFAULT NULL COMMENT '学期',
                                        `exam_id` bigint NOT NULL COMMENT '考试id',
                                        `third_relate_id` bigint DEFAULT NULL COMMENT '云阅卷考试ID',
                                        `third_relate_name` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci DEFAULT NULL COMMENT '云阅卷考试名称',
                                        `paper_number` varchar(50) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL COMMENT '试卷编号',
                                        `course_code` varchar(50) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci DEFAULT NULL COMMENT '课程代码',
                                        `course_name` varchar(255) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci DEFAULT NULL COMMENT '课程名称',
                                        `sequence` varchar(5) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci DEFAULT NULL COMMENT '课程创建的任务序号（和exam_task保持一致）',
                                        `paper_type` varchar(20) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci NOT NULL COMMENT '试卷类型',
                                        `status` varchar(20) CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci DEFAULT NULL COMMENT '状态。INIT：未开始；START：开始同步；PAPER_FINISH：试卷同步成功；ANSWER_FINISH：标答同步成功；OBJECTIVE_FINISH：客观题结构同步成功；SUBJECTIVE_FINISH：主观题结构同步成功；FINISH：结束。',
                                        `paper_answer` text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci COMMENT '试卷原卷和标答附件ID',
                                        `objective_structure` text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci COMMENT '客观题试卷结构JSON',
                                        `subjective_structure` text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci COMMENT '主观题试卷结构JSON',
                                        `paper_info_json` text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci COMMENT '整个试卷信息json（前端提供的全部信息）',
                                        `proposition_teacher_id` bigint DEFAULT NULL COMMENT '命题老师ID',
                                        `enable` tinyint(1) DEFAULT NULL COMMENT '是否启用（0-禁用，1-启用）',
                                        `mark_leader` text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci COMMENT '科组长，样例：[{markerId:1, loginName:"mt01"}]',
                                        `cloud_info_json` text CHARACTER SET utf8mb4 COLLATE utf8mb4_unicode_ci COMMENT '云阅卷试卷结构',
                                        `structure_change` tinyint(1) DEFAULT NULL COMMENT '云阅卷试卷结构和知学知考结构不一样（默认false）',
                                        `create_id` bigint DEFAULT NULL,
                                        `create_time` bigint DEFAULT NULL,
                                        `update_id` bigint DEFAULT NULL,
                                        `update_time` bigint DEFAULT NULL,
                                        PRIMARY KEY (`id`) USING BTREE,
                                        UNIQUE KEY `exam_paper_structure_unique` (`school_id`,`exam_id`,`paper_number`,`paper_type`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for exam_print_plan
-- ----------------------------
DROP TABLE IF EXISTS `exam_print_plan`;
CREATE TABLE `exam_print_plan` (
                                   `id` bigint NOT NULL COMMENT '主键',
                                   `exam_id` bigint NOT NULL COMMENT '考试id',
                                   `school_id` bigint NOT NULL COMMENT '学校id',
                                   `org_id` bigint NOT NULL COMMENT '机构id',
                                   `name` varchar(150) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '名称',
                                   `exam_start_time` bigint NOT NULL COMMENT '考试开始时间',
                                   `exam_end_time` bigint NOT NULL COMMENT '考试结束时间',
                                   `print_content` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '{“PAPER”, "CARD"}',
                                   `backup_method` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'PLACE-按考点，ROOM-按考场',
                                   `backup_count` int NOT NULL COMMENT '备份数量',
                                   `draw_rule` varchar(10) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT 'ONE-只抽一次，CIRCLE-可循环抽取',
                                   `variable_content` text CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '[\n   {\n     "type": "SIGN",\n     "usedId": 1,\n      "backupMethod": "ROOM",\n     "backupCount": 3\n    },\n    {\n     "type": "PACKAG",\n     "usedId": 3,\n      "backupMethod": "STUDENT",\n      "backupCount": 5\n    }\n  ]',
                                   `ordinary_content` text CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '[\n   {\n     "type": "CHECK_IN",\n     "usedId": 1,\n      "backupMethod": "ROOM",\n     "backupCount": 3\n    }\n  ]',
                                   `status` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '印刷计划状态',
                                   `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                   `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                   `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                   `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                   `third_relate_id` bigint DEFAULT NULL COMMENT '第三方系统关联ID（目前只有云阅卷）',
                                   `third_relate_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '第三方系统关联考试名称（目前只有云阅卷）',
                                   `sync_status` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '是否同步成功',
                                   PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='印刷计划管理';

-- ----------------------------
-- Table structure for exam_student
-- ----------------------------
DROP TABLE IF EXISTS `exam_student`;
CREATE TABLE `exam_student` (
                                `id` bigint NOT NULL COMMENT '主键',
                                `school_id` bigint NOT NULL COMMENT '学校id',
                                `org_id` bigint NOT NULL COMMENT '机构id',
                                `exam_detail_course_id` bigint NOT NULL COMMENT '考试明细课程id',
                                `student_name` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '考生姓名',
                                `student_code` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '考生代码',
                                `paper_number` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷编号',
                                `ticket_number` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '准考证号',
                                `site_number` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '座位号',
                                `print_paper` tinyint DEFAULT NULL COMMENT '打印试卷',
                                `print_card` tinyint DEFAULT NULL COMMENT '打印题卡',
                                `extend_fields` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '扩展字段',
                                `paper_type` varchar(2) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷类型',
                                `college_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学生学院名称',
                                `major_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '专业名称',
                                `clazz_id` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '班级Id',
                                `clazz_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '班级名称',
                                `teach_clazz_id` bigint DEFAULT NULL COMMENT '教学班id',
                                `teach_clazz_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教学班名称',
                                `student_clazz_type` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '主体班级类型',
                                `campus_name` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '校区',
                                `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                `attachment_id` bigint DEFAULT NULL COMMENT '附件id',
                                `sync_status` tinyint(1) DEFAULT NULL COMMENT '是否同步成功：true-是， false-否',
                                PRIMARY KEY (`id`) USING BTREE,
                                KEY `exam_student_schoolId_idx` (`school_id`,`student_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考生';

-- ----------------------------
-- Table structure for exam_task
-- ----------------------------
DROP TABLE IF EXISTS `exam_task`;
CREATE TABLE `exam_task` (
                             `id` bigint NOT NULL COMMENT '主键',
                             `exam_id` bigint NOT NULL COMMENT '考试id',
                             `school_id` bigint NOT NULL COMMENT '学校id',
                             `org_id` bigint DEFAULT NULL COMMENT '机构id',
                             `course_code` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程代码',
                             `course_name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程名称',
                             `specialty` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '适用专业',
                             `paper_number` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷编号',
                             `paper_number_id` bigint DEFAULT NULL COMMENT '试卷编号ID（用于推送云阅卷）',
                             `sequence` varchar(5) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程创建的任务序号',
                             `start_time` bigint DEFAULT NULL COMMENT '命题开始时间',
                             `end_time` bigint DEFAULT NULL COMMENT '命题结束时间',
                             `card_rule_id` bigint NOT NULL COMMENT '题卡规则',
                             `user_id` bigint DEFAULT NULL COMMENT '命题老师',
                             `status` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '任务状态，DRAFT：新建，SUBMIT：已提交，STAGE：待命题',
                             `review` tinyint DEFAULT NULL COMMENT '是否审核，0-禁用，1-启用',
                             `review_status` varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '审核状态：PASS-审核通过，NOT_PASS-审核不通过，默认为空-未审核',
                             `enable` tinyint DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
                             `batch_no` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '批次id',
                             `teaching_room_id` bigint DEFAULT NULL COMMENT '教学单位、教研室',
                             `teacher_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '拟卷教师',
                             `lecturer_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '主讲教师',
                             `paper_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷名称',
                             `create_id` bigint DEFAULT NULL COMMENT '创建人',
                             `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                             `update_id` bigint DEFAULT NULL COMMENT '修改人',
                             `update_time` bigint DEFAULT NULL COMMENT '修改时间',
                             `flow_id` bigint DEFAULT NULL COMMENT '流程id',
                             `approve_form_attachment_id` bigint DEFAULT NULL COMMENT '命题任务审批表附件id',
                             PRIMARY KEY (`id`) USING BTREE,
                             KEY `task_schoolId_flowId_idx` (`school_id`,`flow_id`,`card_rule_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='命题任务';

-- ----------------------------
-- Table structure for exam_task_apply_temp
-- ----------------------------
DROP TABLE IF EXISTS `exam_task_apply_temp`;
CREATE TABLE `exam_task_apply_temp` (
                                        `id` bigint unsigned NOT NULL,
                                        `school_id` bigint NOT NULL COMMENT '学校Id',
                                        `org_id` bigint NOT NULL COMMENT '机构id',
                                        `exam_task_content` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '命题任务json',
                                        `create_id` bigint DEFAULT NULL,
                                        `create_time` bigint DEFAULT NULL,
                                        `update_id` bigint DEFAULT NULL,
                                        `update_time` bigint DEFAULT NULL,
                                        PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='卷库查询-命题任务申请临时表';

-- ----------------------------
-- Table structure for exam_task_detail
-- ----------------------------
DROP TABLE IF EXISTS `exam_task_detail`;
CREATE TABLE `exam_task_detail` (
                                    `id` bigint NOT NULL COMMENT '主键',
                                    `exam_task_id` bigint NOT NULL COMMENT '命题任务ID',
                                    `paper_type` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷类型，多个以”/“分隔，如A/B/C/D',
                                    `draw_count` int DEFAULT NULL COMMENT '单次抽卷数量',
                                    `paper_attachment_ids` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '转换为A3格式的试卷附件\n[\\n    {\\n      "type": "A",\\n     "attachmentId": 12,\\n      "totalPages": 3\\n    },\\n   {\\n      "type": "B",\\n     "attachmentId": 13,\\n      "totalPages": 2\\n    }\\n  ]',
                                    `make_method` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '题卡绑定方式',
                                    `paper_confirm_attachment_ids` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '[\n   {\n     "attachmentId": 12\n    },\n    {\n     "attachmentId": 13\n    }\n  ]',
                                    `remark` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '备注',
                                    `exposed_paper_type` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '曝光卷型：已打印卷型，多个以”/“分隔，如A/B/C/D',
                                    `relate_paper_type` varchar(5) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '已曝光卷型',
                                    `unexposed_paper_type` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '未曝光卷型',
                                    `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                    `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                    `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                    `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                    `enable` tinyint DEFAULT '1' COMMENT '0-禁用，1-启用',
                                    PRIMARY KEY (`id`) USING BTREE,
                                    KEY `exam_task_detail_idx` (`exam_task_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='命题任务明细表（入库申请）';

-- ----------------------------
-- Table structure for exam_task_paper_log
-- ----------------------------
DROP TABLE IF EXISTS `exam_task_paper_log`;
CREATE TABLE `exam_task_paper_log` (
                                       `id` bigint NOT NULL COMMENT '主键',
                                       `exam_task_id` bigint NOT NULL COMMENT '命题任务ID',
                                       `paper_type` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷类型',
                                       `paper_attachment_ids` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '修改后试卷',
                                       `card_id` bigint DEFAULT NULL COMMENT '修改后题卡ID',
                                       `review` tinyint(1) DEFAULT NULL COMMENT '是否审核：true-审核，false-未审核',
                                       `review_status` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '审核状态：PASS-通过，NOT_PASS-不通过',
                                       `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                       `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                       `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                       `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                       PRIMARY KEY (`id`) USING BTREE,
                                       KEY `exam_task_paper_idx` (`exam_task_id`,`review`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='卷库修改审核临时表';

-- ----------------------------
-- Table structure for exam_task_print
-- ----------------------------
DROP TABLE IF EXISTS `exam_task_print`;
CREATE TABLE `exam_task_print` (
                                   `id` bigint NOT NULL,
                                   `school_id` bigint DEFAULT NULL,
                                   `org_id` bigint DEFAULT NULL,
                                   `print_plan_id` bigint DEFAULT NULL COMMENT '印刷计划ID',
                                   `course_code` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程代码',
                                   `course_name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程名称',
                                   `paper_number` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷编号',
                                   `exam_start_time` bigint DEFAULT NULL COMMENT '考试开始时间',
                                   `exam_end_time` bigint DEFAULT NULL COMMENT '考试结束时间',
                                   `package_seq` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '卷袋序号',
                                   `exam_place` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                   `exam_room` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                   `invigilator_teacher` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '监考老师',
                                   `class_id` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '班级ID集合',
                                   `class_name` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '班级名称集合',
                                   `student_count` int DEFAULT NULL COMMENT '考生总人数',
                                   `campus_id` bigint DEFAULT NULL COMMENT '校区ID',
                                   `print_house_id` bigint DEFAULT NULL COMMENT '印刷室ID',
                                   `print_house_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '印刷室名称',
                                   `exam_detail_id` bigint DEFAULT NULL COMMENT '考场ID',
                                   `extend_fields` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '扩展字段',
                                   `create_id` bigint DEFAULT NULL,
                                   `create_time` bigint DEFAULT NULL,
                                   `update_id` bigint DEFAULT NULL,
                                   `update_time` bigint DEFAULT NULL,
                                   PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='以试卷作为起点生成考务数据';

-- ----------------------------
-- Table structure for exam_task_review_log
-- ----------------------------
DROP TABLE IF EXISTS `exam_task_review_log`;
CREATE TABLE `exam_task_review_log` (
                                        `id` bigint NOT NULL COMMENT '主键',
                                        `exam_task_id` bigint NOT NULL COMMENT '命题任务ID',
                                        `review_status` varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'PASS-通过，NOT_PASS-不通过',
                                        `reason` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '审核意见',
                                        `operate_id` bigint DEFAULT NULL COMMENT '操作人id',
                                        `operate_time` bigint DEFAULT NULL COMMENT '操作时间',
                                        `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                        `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                        `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                        `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                        PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='命题任务审核日志表';

-- ----------------------------
-- Table structure for exam_task_temp
-- ----------------------------
DROP TABLE IF EXISTS `exam_task_temp`;
CREATE TABLE `exam_task_temp` (
                                  `id` bigint NOT NULL COMMENT '主键',
                                  `school_id` bigint NOT NULL COMMENT '学校id',
                                  `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                  `batch_no` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '本次导入数据临时ID',
                                  `course_code` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程代码',
                                  `course_name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程名称',
                                  `paper_number` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷编号',
                                  `specialty` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '适用专业',
                                  `user_account` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '命题老师账号',
                                  `user_name` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '命题老师姓名',
                                  `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                  `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='命题任务临时表';

-- ----------------------------
-- Table structure for grade_batch
-- ----------------------------
DROP TABLE IF EXISTS `grade_batch`;
CREATE TABLE `grade_batch` (
                               `id` bigint NOT NULL COMMENT '分析批次主键',
                               `school_id` bigint NOT NULL COMMENT '学校id',
                               `org_id` bigint NOT NULL COMMENT '机构id',
                               `semester_id` bigint NOT NULL COMMENT '学期id',
                               `batch_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '批次编号（在学校下唯一）',
                               `batch_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '批次名称（2020~2021学年上学期期末考试）',
                               `batch_time` bigint NOT NULL COMMENT '分析批次时间',
                               `status` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '批次状态\nSETTING_GRADE_PAPER("设置分析试卷"),PUSH_GRADE_BATCH("推送教研分析批次数据"),SETTING_GRADE_PAPER_PARAM("设置分析试卷参数"),READY_TO_CALCULATE("待计算"),FINISH_CALCULATE("完成计算")',
                               `third_semester_id` bigint DEFAULT NULL COMMENT '教研分析学期id',
                               `third_exam_id` bigint DEFAULT NULL COMMENT '第三方考试id',
                               `create_id` bigint DEFAULT NULL,
                               `create_time` bigint DEFAULT NULL,
                               `update_id` bigint DEFAULT NULL,
                               `update_time` bigint DEFAULT NULL,
                               `source` varchar(1000) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '原始数据',
                               `progress` decimal(8,2) DEFAULT NULL COMMENT '进度',
                               `report_file_path` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '报告路径',
                               `notify_time` bigint DEFAULT NULL COMMENT '回调时间',
                               `result` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '数据结果，SUCCESS：成功，ERROR：失败',
                               PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='分析-批次表';

-- ----------------------------
-- Table structure for grade_batch_paper
-- ----------------------------
DROP TABLE IF EXISTS `grade_batch_paper`;
CREATE TABLE `grade_batch_paper` (
                                     `id` bigint NOT NULL,
                                     `school_id` bigint NOT NULL COMMENT '学校id',
                                     `org_id` bigint NOT NULL COMMENT '机构id',
                                     `batch_id` bigint NOT NULL COMMENT '分析批次id',
                                     `grade_paper_id` bigint DEFAULT NULL COMMENT '试卷id',
                                     `paper_number` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷编号',
                                     `paper_type` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷类型',
                                     `status` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '分析试卷状态\nSETTING_GRADE_PAPER("设置分析试卷"),PUSH_GRADE_BATCH("推送教研分析批次数据"),SETTING_GRADE_PAPER_PARAM("设置分析试卷参数"),READY_TO_CALCULATE("待计算"),FINISH_CALCULATE("完成计算")',
                                     `teach_college_id` bigint NOT NULL COMMENT '当前开课学院id',
                                     `teach_college_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '当前开课学院名称',
                                     `paper_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷名称',
                                     `enable` tinyint DEFAULT NULL COMMENT '是否可用',
                                     `publish_status` tinyint DEFAULT NULL COMMENT '是否发布',
                                     `grade_course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '推送教研分析后回传的教研分析课程编号（考试下唯一）',
                                     `create_id` bigint DEFAULT NULL,
                                     `create_time` bigint DEFAULT NULL,
                                     `update_id` bigint DEFAULT NULL,
                                     `update_time` bigint DEFAULT NULL,
                                     PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='分析-批次试卷关联关系表';

-- ----------------------------
-- Table structure for grade_batch_student
-- ----------------------------
DROP TABLE IF EXISTS `grade_batch_student`;
CREATE TABLE `grade_batch_student` (
                                       `id` bigint NOT NULL,
                                       `batch_id` bigint DEFAULT NULL COMMENT '分析-批次表ID',
                                       `course_code` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程编码',
                                       `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程名称',
                                       `paper_number` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷编号',
                                       `paper_type` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷类型',
                                       `student_code` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学号',
                                       `student_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学生姓名',
                                       `ticket_number` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '准考证号',
                                       `teacher_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '任课老师',
                                       `teacher_number` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '任课老师工号',
                                       `create_id` bigint DEFAULT NULL,
                                       `create_time` bigint DEFAULT NULL,
                                       `update_id` bigint DEFAULT NULL,
                                       `update_time` bigint DEFAULT NULL,
                                       PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='考务数据（包含任课老师）';

-- ----------------------------
-- Table structure for grade_batch_student_clazz
-- ----------------------------
DROP TABLE IF EXISTS `grade_batch_student_clazz`;
CREATE TABLE `grade_batch_student_clazz` (
                                             `id` bigint NOT NULL,
                                             `batch_id` bigint DEFAULT NULL COMMENT '分析-批次表ID',
                                             `course_code` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程编码',
                                             `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '课程名称',
                                             `paper_number` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷编号',
                                             `paper_type` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷类型',
                                             `clazz_id` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '班级ID',
                                             `clazz_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '班级名称',
                                             `teacher_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '任课老师',
                                             `teacher_number` varchar(45) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '任课老师工号',
                                             `create_id` bigint DEFAULT NULL,
                                             `create_time` bigint DEFAULT NULL,
                                             `update_id` bigint DEFAULT NULL,
                                             `update_time` bigint DEFAULT NULL,
                                             PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci ROW_FORMAT=DYNAMIC COMMENT='考务数据班级（包含任课老师）';

-- ----------------------------
-- Table structure for grade_module_define
-- ----------------------------
DROP TABLE IF EXISTS `grade_module_define`;
CREATE TABLE `grade_module_define` (
                                       `id` bigint NOT NULL COMMENT '模块熟练度主键',
                                       `school_id` bigint NOT NULL COMMENT '学校id',
                                       `paper_number` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷编号',
                                       `paper_type` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷类型',
                                       `paper_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷名称',
                                       `module_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '维度模块类型',
                                       `interpret` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '解释',
                                       `remark` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '备注',
                                       `define` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '二级熟练度定义',
                                       `level` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '等级',
                                       `min` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '展示用最小边界',
                                       `max` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '展示用最大边界',
                                       `scope` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '取值范围（计算用）',
                                       `create_id` bigint DEFAULT NULL,
                                       `create_time` bigint DEFAULT NULL,
                                       `update_id` bigint DEFAULT NULL,
                                       `update_time` bigint DEFAULT NULL,
                                       PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='分析-模块二级考察点维度熟练度配置，及模块简要描述表';

-- ----------------------------
-- Table structure for grade_module_evaluation
-- ----------------------------
DROP TABLE IF EXISTS `grade_module_evaluation`;
CREATE TABLE `grade_module_evaluation` (
                                           `id` bigint NOT NULL,
                                           `school_id` bigint NOT NULL COMMENT '学校id',
                                           `paper_number` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷编号',
                                           `paper_type` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷类型',
                                           `paper_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷名称',
                                           `module_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '模块类型（知识、维度、素养）',
                                           `formula` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '计算公式规则',
                                           `scope` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '取值范围（计算用）',
                                           `level_code` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '等级',
                                           `level_name` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '水平等级层次',
                                           `result` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '诊断结果',
                                           `advice` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '学习建议',
                                           `create_id` bigint DEFAULT NULL,
                                           `create_time` bigint DEFAULT NULL,
                                           `update_id` bigint DEFAULT NULL,
                                           `update_time` bigint DEFAULT NULL,
                                           PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='校验-考察点模块评价建议表';

-- ----------------------------
-- Table structure for grade_paper
-- ----------------------------
DROP TABLE IF EXISTS `grade_paper`;
CREATE TABLE `grade_paper` (
                               `id` bigint NOT NULL COMMENT '试卷id',
                               `school_id` bigint NOT NULL COMMENT '学校id',
                               `paper_number` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷编号',
                               `paper_type` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷类型',
                               `paper_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷名称',
                               `start_time` bigint DEFAULT NULL COMMENT '该试卷考试开始时间',
                               `end_time` bigint DEFAULT NULL COMMENT '该试卷考试结束时间',
                               `coefficient` decimal(12,4) DEFAULT NULL COMMENT '赋分系数（赋值分=卷面成绩 +（卷面满分-卷面成绩）/ 赋分系数）',
                               `total_score` decimal(12,4) NOT NULL COMMENT '试卷满分',
                               `pass_score` decimal(12,4) NOT NULL COMMENT '试卷及格分',
                               `score_type` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '赋分类型\\n1.NEED_ASSIGN_SCORE("是","需要且按照公式赋分")\\n2.NO_NEED_ASSIGN_SCORE("否","不需要赋分，标准分即为赋分")\\n3.SPECIAL_ASSIGN_SCORE("特殊赋分","特殊赋分，按照excel表进行赋分")',
                               `create_id` bigint DEFAULT NULL,
                               `create_time` bigint DEFAULT NULL,
                               `update_id` bigint DEFAULT NULL,
                               `update_time` bigint DEFAULT NULL,
                               PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='试卷基础信息表（赋分系数、试卷类型、满分、及格分等）';

-- ----------------------------
-- Table structure for grade_paper_dimension
-- ----------------------------
DROP TABLE IF EXISTS `grade_paper_dimension`;
CREATE TABLE `grade_paper_dimension` (
                                         `id` bigint NOT NULL,
                                         `school_id` bigint NOT NULL COMMENT '学校id',
                                         `paper_number` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷编号',
                                         `paper_type` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷类型',
                                         `paper_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷名称',
                                         `dimension_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '维度类型 - 知识，能力，素养',
                                         `code_primary` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '一级维度编号',
                                         `name_primary` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '一级维度名称',
                                         `code_second` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '二级维度编号',
                                         `name_second` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '二级维度名称',
                                         `interpretation` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '一级维度术语解释',
                                         `create_id` bigint DEFAULT NULL,
                                         `create_time` bigint DEFAULT NULL,
                                         `update_id` bigint DEFAULT NULL,
                                         `update_time` bigint DEFAULT NULL,
                                         PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='分析-考察点维度表';

-- ----------------------------
-- Table structure for grade_paper_struct
-- ----------------------------
DROP TABLE IF EXISTS `grade_paper_struct`;
CREATE TABLE `grade_paper_struct` (
                                      `id` bigint NOT NULL,
                                      `school_id` bigint NOT NULL COMMENT '学校id',
                                      `paper_number` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷编号',
                                      `paper_type` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷类型',
                                      `paper_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '试卷名称',
                                      `question_name` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '大题名称',
                                      `number_type` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '题号类型（客观题、主观题）',
                                      `big_question_number` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '大题号',
                                      `small_question_number` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '小题号(每一课程试卷的唯一标识)',
                                      `big_topic_name` varchar(64) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '大题名称',
                                      `full_score` decimal(12,4) NOT NULL COMMENT '满分',
                                      `score_rules` varchar(32) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '计分规则',
                                      `rules_desc` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '规则说明',
                                      `knowledge_dimension` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '知识维度',
                                      `ability_dimension` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '能力维度',
                                      `literacy_dimension` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '素养维度',
                                      `create_id` bigint DEFAULT NULL,
                                      `create_time` bigint DEFAULT NULL,
                                      `update_id` bigint DEFAULT NULL,
                                      `update_time` bigint DEFAULT NULL,
                                      PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='分析-试卷结构（蓝图）表';

-- ----------------------------
-- Table structure for qrtz_blob_triggers
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_blob_triggers`;
CREATE TABLE `qrtz_blob_triggers` (
                                      `SCHED_NAME` varchar(120) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                      `TRIGGER_NAME` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                      `TRIGGER_GROUP` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                      `BLOB_DATA` blob,
                                      PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE,
                                      KEY `SCHED_NAME` (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_calendars
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_calendars`;
CREATE TABLE `qrtz_calendars` (
                                  `SCHED_NAME` varchar(120) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                  `CALENDAR_NAME` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                  `CALENDAR` blob NOT NULL,
                                  PRIMARY KEY (`SCHED_NAME`,`CALENDAR_NAME`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_cron_triggers
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_cron_triggers`;
CREATE TABLE `qrtz_cron_triggers` (
                                      `SCHED_NAME` varchar(120) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                      `TRIGGER_NAME` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                      `TRIGGER_GROUP` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                      `CRON_EXPRESSION` varchar(120) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                      `TIME_ZONE_ID` varchar(80) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                      PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_fired_triggers
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_fired_triggers`;
CREATE TABLE `qrtz_fired_triggers` (
                                       `SCHED_NAME` varchar(120) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                       `ENTRY_ID` varchar(95) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                       `TRIGGER_NAME` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                       `TRIGGER_GROUP` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                       `INSTANCE_NAME` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                       `FIRED_TIME` bigint NOT NULL,
                                       `SCHED_TIME` bigint NOT NULL,
                                       `PRIORITY` int NOT NULL,
                                       `STATE` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                       `JOB_NAME` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                       `JOB_GROUP` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                       `IS_NONCONCURRENT` varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                       `REQUESTS_RECOVERY` varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                       PRIMARY KEY (`SCHED_NAME`,`ENTRY_ID`) USING BTREE,
                                       KEY `IDX_QRTZ_FT_TRIG_INST_NAME` (`SCHED_NAME`,`INSTANCE_NAME`) USING BTREE,
                                       KEY `IDX_QRTZ_FT_INST_JOB_REQ_RCVRY` (`SCHED_NAME`,`INSTANCE_NAME`,`REQUESTS_RECOVERY`) USING BTREE,
                                       KEY `IDX_QRTZ_FT_J_G` (`SCHED_NAME`,`JOB_NAME`,`JOB_GROUP`) USING BTREE,
                                       KEY `IDX_QRTZ_FT_JG` (`SCHED_NAME`,`JOB_GROUP`) USING BTREE,
                                       KEY `IDX_QRTZ_FT_T_G` (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE,
                                       KEY `IDX_QRTZ_FT_TG` (`SCHED_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_job_details
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_job_details`;
CREATE TABLE `qrtz_job_details` (
                                    `SCHED_NAME` varchar(120) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                    `JOB_NAME` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                    `JOB_GROUP` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                    `DESCRIPTION` varchar(250) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                    `JOB_CLASS_NAME` varchar(250) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                    `IS_DURABLE` varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                    `IS_NONCONCURRENT` varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                    `IS_UPDATE_DATA` varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                    `REQUESTS_RECOVERY` varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                    `JOB_DATA` blob,
                                    PRIMARY KEY (`SCHED_NAME`,`JOB_NAME`,`JOB_GROUP`) USING BTREE,
                                    KEY `IDX_QRTZ_J_REQ_RECOVERY` (`SCHED_NAME`,`REQUESTS_RECOVERY`) USING BTREE,
                                    KEY `IDX_QRTZ_J_GRP` (`SCHED_NAME`,`JOB_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_locks
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_locks`;
CREATE TABLE `qrtz_locks` (
                              `SCHED_NAME` varchar(120) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                              `LOCK_NAME` varchar(40) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                              PRIMARY KEY (`SCHED_NAME`,`LOCK_NAME`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_paused_trigger_grps
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_paused_trigger_grps`;
CREATE TABLE `qrtz_paused_trigger_grps` (
                                            `SCHED_NAME` varchar(120) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                            `TRIGGER_GROUP` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                            PRIMARY KEY (`SCHED_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_scheduler_state
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_scheduler_state`;
CREATE TABLE `qrtz_scheduler_state` (
                                        `SCHED_NAME` varchar(120) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                        `INSTANCE_NAME` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                        `LAST_CHECKIN_TIME` bigint NOT NULL,
                                        `CHECKIN_INTERVAL` bigint NOT NULL,
                                        PRIMARY KEY (`SCHED_NAME`,`INSTANCE_NAME`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_simple_triggers
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_simple_triggers`;
CREATE TABLE `qrtz_simple_triggers` (
                                        `SCHED_NAME` varchar(120) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                        `TRIGGER_NAME` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                        `TRIGGER_GROUP` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                        `REPEAT_COUNT` bigint NOT NULL,
                                        `REPEAT_INTERVAL` bigint NOT NULL,
                                        `TIMES_TRIGGERED` bigint NOT NULL,
                                        PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_simprop_triggers
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_simprop_triggers`;
CREATE TABLE `qrtz_simprop_triggers` (
                                         `SCHED_NAME` varchar(120) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                         `TRIGGER_NAME` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                         `TRIGGER_GROUP` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                         `STR_PROP_1` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                         `STR_PROP_2` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                         `STR_PROP_3` varchar(512) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                         `INT_PROP_1` int DEFAULT NULL,
                                         `INT_PROP_2` int DEFAULT NULL,
                                         `LONG_PROP_1` bigint DEFAULT NULL,
                                         `LONG_PROP_2` bigint DEFAULT NULL,
                                         `DEC_PROP_1` decimal(13,4) DEFAULT NULL,
                                         `DEC_PROP_2` decimal(13,4) DEFAULT NULL,
                                         `BOOL_PROP_1` varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                         `BOOL_PROP_2` varchar(1) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                         PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for qrtz_triggers
-- ----------------------------
DROP TABLE IF EXISTS `qrtz_triggers`;
CREATE TABLE `qrtz_triggers` (
                                 `SCHED_NAME` varchar(120) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                 `TRIGGER_NAME` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                 `TRIGGER_GROUP` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                 `JOB_NAME` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                 `JOB_GROUP` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                 `DESCRIPTION` varchar(250) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                 `NEXT_FIRE_TIME` bigint DEFAULT NULL,
                                 `PREV_FIRE_TIME` bigint DEFAULT NULL,
                                 `PRIORITY` int DEFAULT NULL,
                                 `TRIGGER_STATE` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                 `TRIGGER_TYPE` varchar(8) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL,
                                 `START_TIME` bigint NOT NULL,
                                 `END_TIME` bigint DEFAULT NULL,
                                 `CALENDAR_NAME` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL,
                                 `MISFIRE_INSTR` smallint DEFAULT NULL,
                                 `JOB_DATA` blob,
                                 PRIMARY KEY (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`) USING BTREE,
                                 KEY `IDX_QRTZ_T_J` (`SCHED_NAME`,`JOB_NAME`,`JOB_GROUP`) USING BTREE,
                                 KEY `IDX_QRTZ_T_JG` (`SCHED_NAME`,`JOB_GROUP`) USING BTREE,
                                 KEY `IDX_QRTZ_T_C` (`SCHED_NAME`,`CALENDAR_NAME`) USING BTREE,
                                 KEY `IDX_QRTZ_T_G` (`SCHED_NAME`,`TRIGGER_GROUP`) USING BTREE,
                                 KEY `IDX_QRTZ_T_STATE` (`SCHED_NAME`,`TRIGGER_STATE`) USING BTREE,
                                 KEY `IDX_QRTZ_T_N_STATE` (`SCHED_NAME`,`TRIGGER_NAME`,`TRIGGER_GROUP`,`TRIGGER_STATE`) USING BTREE,
                                 KEY `IDX_QRTZ_T_N_G_STATE` (`SCHED_NAME`,`TRIGGER_GROUP`,`TRIGGER_STATE`) USING BTREE,
                                 KEY `IDX_QRTZ_T_NEXT_FIRE_TIME` (`SCHED_NAME`,`NEXT_FIRE_TIME`) USING BTREE,
                                 KEY `IDX_QRTZ_T_NFT_ST` (`SCHED_NAME`,`TRIGGER_STATE`,`NEXT_FIRE_TIME`) USING BTREE,
                                 KEY `IDX_QRTZ_T_NFT_MISFIRE` (`SCHED_NAME`,`MISFIRE_INSTR`,`NEXT_FIRE_TIME`) USING BTREE,
                                 KEY `IDX_QRTZ_T_NFT_ST_MISFIRE` (`SCHED_NAME`,`MISFIRE_INSTR`,`NEXT_FIRE_TIME`,`TRIGGER_STATE`) USING BTREE,
                                 KEY `IDX_QRTZ_T_NFT_ST_MISFIRE_GRP` (`SCHED_NAME`,`MISFIRE_INSTR`,`NEXT_FIRE_TIME`,`TRIGGER_GROUP`,`TRIGGER_STATE`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci;

-- ----------------------------
-- Table structure for sys_config
-- ----------------------------
DROP TABLE IF EXISTS `sys_config`;
CREATE TABLE `sys_config` (
                              `id` bigint NOT NULL COMMENT '主键',
                              `school_id` bigint DEFAULT NULL COMMENT '学校id',
                              `org_id` bigint DEFAULT NULL COMMENT '机构id',
                              `config_key` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '参数键名',
                              `config_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '参数名称',
                              `config_value` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '参数键值',
                              `remark` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '备注',
                              `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                              `sort` int DEFAULT '1' COMMENT '排序',
                              `create_id` bigint DEFAULT NULL COMMENT '创建人',
                              `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                              `update_id` bigint DEFAULT NULL COMMENT '更新人',
                              `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                              PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='参数表';

-- ----------------------------
-- Table structure for sys_org
-- ----------------------------
DROP TABLE IF EXISTS `sys_org`;
CREATE TABLE `sys_org` (
                           `id` bigint NOT NULL COMMENT '主键',
                           `school_id` bigint NOT NULL COMMENT '学校id',
                           `type` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '类型，SCHOOL：学校，COLLEGE：学院，FACULTY：院系，TEACHING_ROOM：教研室，PRINTING_HOUSE：印刷厂',
                           `code` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '机构代码',
                           `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '机构名称',
                           `parent_id` bigint DEFAULT NULL COMMENT '上级机构id',
                           `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                           `create_id` bigint DEFAULT NULL COMMENT '创建人',
                           `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                           `update_id` bigint DEFAULT NULL COMMENT '修改人',
                           `update_time` bigint DEFAULT NULL COMMENT '修改时间',
                           `historic_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '历史机构名称',
                           PRIMARY KEY (`id`) USING BTREE,
                           UNIQUE KEY `org_schoolId_name_idx` (`school_id`,`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校组织架构';

-- ----------------------------
-- Table structure for sys_privilege
-- ----------------------------
DROP TABLE IF EXISTS `sys_privilege`;
CREATE TABLE `sys_privilege` (
                                 `id` bigint NOT NULL COMMENT '主键',
                                 `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '菜单名称',
                                 `url` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT 'URL地址',
                                 `type` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '类型，MENU：菜单，BUTTON：按钮，LINK：链接，URL：接口地址，LIST：列表，CONDITION：查询条件，TAB：选项卡',
                                 `parent_id` bigint DEFAULT NULL COMMENT '上级菜单',
                                 `sequence` int NOT NULL COMMENT '序号',
                                 `property` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '属性，NO_AUTH：无需鉴权，AUTH：鉴权，SYS：系统公用',
                                 `related` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '关联属性，type为URL且property为AUTH才有',
                                 `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                 `default_auth` tinyint DEFAULT '1' COMMENT '默认权限，0：否，1：是',
                                 `front_display` tinyint(1) DEFAULT '1' COMMENT '是否前端展示',
                                 PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='菜单权限表';

-- ----------------------------
-- Table structure for sys_role
-- ----------------------------
DROP TABLE IF EXISTS `sys_role`;
CREATE TABLE `sys_role` (
                            `id` bigint NOT NULL COMMENT '主键',
                            `school_id` bigint DEFAULT NULL COMMENT '学校id',
                            `org_id` bigint DEFAULT NULL COMMENT '机构id',
                            `name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '角色名称',
                            `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                            `type` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '角色类别，ADMIN：超级管理员，SCHOOL_ADMIN：管理员：EXAM_TEACHER：考务老师，QUESTION_TEACHER：命题老师，CUSTOMER：客服人员，PRINTER：印刷人员，CUSTOM：自定义',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `update_id` bigint DEFAULT NULL COMMENT '修改人',
                            `update_time` bigint DEFAULT NULL COMMENT '修改时间',
                            `default_role` tinyint NOT NULL DEFAULT '0' COMMENT '是否系统内置角色，1：是，0：不是',
                            `source` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '角色来源，ANALYSIS：教研分析',
                            `interpret` varchar(1000) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '角色说明',
                            PRIMARY KEY (`id`) USING BTREE,
                            UNIQUE KEY `role_schoolId_name_idx` (`school_id`,`name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='角色表';

-- ----------------------------
-- Table structure for sys_role_group_member
-- ----------------------------
DROP TABLE IF EXISTS `sys_role_group_member`;
CREATE TABLE `sys_role_group_member` (
                                         `id` bigint NOT NULL COMMENT '主键',
                                         `role_id` bigint NOT NULL COMMENT '角色id',
                                         `user_id` bigint NOT NULL COMMENT '用户id',
                                         `member_id` bigint NOT NULL COMMENT '成员id',
                                         `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                         PRIMARY KEY (`id`) USING BTREE,
                                         UNIQUE KEY `role_group_roleId_memberId_idx` (`role_id`,`member_id`,`enable`) USING BTREE,
                                         KEY `role_group_member_idx` (`role_id`,`user_id`,`member_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='角色组成员表';

-- ----------------------------
-- Table structure for sys_role_privilege
-- ----------------------------
DROP TABLE IF EXISTS `sys_role_privilege`;
CREATE TABLE `sys_role_privilege` (
                                      `id` bigint NOT NULL COMMENT '主键',
                                      `role_id` bigint NOT NULL COMMENT '角色id',
                                      `privilege_id` bigint NOT NULL COMMENT '菜单id',
                                      `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                      PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='角色和菜单关联表';

-- ----------------------------
-- Table structure for sys_user
-- ----------------------------
DROP TABLE IF EXISTS `sys_user`;
CREATE TABLE `sys_user` (
                            `id` bigint NOT NULL COMMENT '主键',
                            `school_id` bigint DEFAULT NULL COMMENT '学校id',
                            `login_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '用户名',
                            `real_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '姓名',
                            `code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '工号',
                            `password` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '密码',
                            `mobile_number` varchar(11) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '手机号',
                            `org_id` bigint DEFAULT NULL COMMENT '机构id',
                            `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                            `pwd_count` tinyint DEFAULT '0' COMMENT '密码修改次数，默认为0',
                            `pwd_update_time` bigint DEFAULT NULL COMMENT '密码修改时间',
                            `remark` varchar(200) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '备注',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `update_id` bigint DEFAULT NULL COMMENT '修改人',
                            `update_time` bigint DEFAULT NULL COMMENT '修改时间',
                            `historic_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '历史用户名称',
                            PRIMARY KEY (`id`) USING BTREE,
                            UNIQUE KEY `user_schoolId_loginName_idx` (`school_id`,`login_name`) USING BTREE,
                            UNIQUE KEY `uq_school_id_mobile_number` (`school_id`,`mobile_number`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='用户表';

-- ----------------------------
-- Table structure for sys_user_role
-- ----------------------------
DROP TABLE IF EXISTS `sys_user_role`;
CREATE TABLE `sys_user_role` (
                                 `id` bigint NOT NULL COMMENT '主键',
                                 `user_id` bigint NOT NULL COMMENT '用户id',
                                 `role_id` bigint NOT NULL COMMENT '角色id',
                                 `privilege_id` bigint DEFAULT NULL COMMENT '权限id',
                                 `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                 PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='用户和角色关联表';

-- ----------------------------
-- Table structure for t_b_session
-- ----------------------------
DROP TABLE IF EXISTS `t_b_session`;
CREATE TABLE `t_b_session` (
                               `id` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '主键',
                               `school_id` bigint DEFAULT NULL COMMENT '学校id',
                               `org_id` bigint DEFAULT NULL COMMENT '机构id',
                               `identity` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '用户标识',
                               `type` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '用户类型',
                               `source` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '访问来源',
                               `platform` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备分类',
                               `device_id` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '设备标识',
                               `address` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '登录IP地址',
                               `access_token` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '访问令牌',
                               `last_access_time` bigint DEFAULT NULL COMMENT '最近访问时间',
                               `last_access_ip` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '最近访问IP地址',
                               `update_time` bigint DEFAULT NULL COMMENT '令牌更新时间',
                               `expire_time` bigint DEFAULT NULL COMMENT '令牌强制失效时间',
                               `app_source` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '应用来源',
                               PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='会话表';

-- ----------------------------
-- Table structure for t_b_sync_task
-- ----------------------------
DROP TABLE IF EXISTS `t_b_sync_task`;
CREATE TABLE `t_b_sync_task` (
                                 `id` bigint NOT NULL COMMENT '主键',
                                 `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                 `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                 `type` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '推送类型，USER_PUSH：用户推送',
                                 `third_relate_id` bigint DEFAULT NULL COMMENT '第三方系统关联ID（目前只有云阅卷）',
                                 `object_id` bigint DEFAULT NULL COMMENT '印刷计划id',
                                 `status` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '任务状态，INIT：未开始，RUNNING：进行中，FINISH：已完成',
                                 `summary` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '实时摘要信息',
                                 `result` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '数据结果，SUCCESS：成功，ERROR：失败',
                                 `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                 `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                 `update_id` bigint DEFAULT NULL COMMENT '修改人',
                                 `update_time` bigint DEFAULT NULL COMMENT '修改时间',
                                 `remark` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '备注',
                                 `reset_count` int DEFAULT '0' COMMENT '重试次数',
                                 `error_message` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '人工错误原因',
                                 `report_file_path` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '报告路径',
                                 PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='云阅卷同步任务表';

-- ----------------------------
-- Table structure for t_b_task
-- ----------------------------
DROP TABLE IF EXISTS `t_b_task`;
CREATE TABLE `t_b_task` (
                            `id` bigint NOT NULL COMMENT '主键',
                            `type` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '任务类型，USER_IMPORT：用户导入，\nQUESTION_MISSION_BATCH_CREATE：批量新建命题任务，\nSAMPLE_EXPORT：导出审核样本，\nPAPER_DOWNLOAD：卷库下载，\nEXAMINATION_IMPORT：考务数据导入，\nEXAMINATION_EXPORT：考务数据导出，\nPRINT_PDF_DOWNLOAD：批量下载pdf，\nCREATE_PDF：生成pdf，\nCOURSE_IMPORT：课程导入',
                            `entity_id` bigint DEFAULT NULL COMMENT '关联业务对象id',
                            `status` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '任务状态，INIT：未开始，RUNNING：进行中，FINISH：已完成',
                            `summary` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '实时摘要信息',
                            `progress` double DEFAULT NULL COMMENT '执行进度',
                            `result` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '数据结果，SUCCESS：成功，ERROR：失败',
                            `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，false：停用，true：启用',
                            `import_file_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '导入文件名',
                            `import_file_path` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '导入文件路径',
                            `result_file_path` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '导出文件路径',
                            `error_file_path` varchar(500) DEFAULT NULL COMMENT '错误数据文件路径',
                            `report_file_path` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '报告路径',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `update_id` bigint DEFAULT NULL COMMENT '更新人',
                            `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人',
                            `school_id` bigint DEFAULT NULL COMMENT '学校id',
                            `org_id` bigint DEFAULT NULL COMMENT '机构id',
                            `print_plan_id` bigint DEFAULT NULL COMMENT '印刷计划id',
                            `remark` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '备注',
                            `obj_name` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '实体名称',
                            `reset_count` int DEFAULT '0' COMMENT '重试次数',
                            `version` int DEFAULT '0' COMMENT '更新版本号',
                            `error_message` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '人工错误原因',
                            PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='导入导出任务表';

-- ----------------------------
-- Table structure for t_c_statistics
-- ----------------------------
DROP TABLE IF EXISTS `t_c_statistics`;
CREATE TABLE `t_c_statistics` (
                                  `id` bigint NOT NULL COMMENT '主键',
                                  `exam_id` bigint NOT NULL COMMENT '考试id',
                                  `exam_task_detail_ids` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '命题任务明细id',
                                  `exam_detail_course_ids` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '考务数据课程id',
                                  `college_id` bigint NOT NULL COMMENT '学院id',
                                  `college_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '学院名称',
                                  `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程名称',
                                  `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程代码',
                                  `teaching_room_id` bigint NOT NULL COMMENT '教研室id',
                                  `teaching_room_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '教研室名称',
                                  `teacher_name` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '任课老师名称',
                                  `clazz_ids` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '班级ids',
                                  `clazz_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '班级名称',
                                  `paper_number` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷编号',
                                  `print_plan_id` bigint DEFAULT NULL COMMENT '印刷计划id',
                                  `batch_no` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '批次号',
                                  `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                  `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                  `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                  `print_sum` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '总印份数',
                                  `status` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '完成状态，FINISH：已完成，UN_FINISH：未完成',
                                  `exam_detail_id` bigint DEFAULT NULL COMMENT '命题明细id',
                                  `clazz_content` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '班级详细信息内容',
                                  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='命题统计表';

-- ----------------------------
-- Table structure for t_c_statistics_temp
-- ----------------------------
DROP TABLE IF EXISTS `t_c_statistics_temp`;
CREATE TABLE `t_c_statistics_temp` (
                                       `id` bigint NOT NULL COMMENT '主键',
                                       `exam_id` bigint NOT NULL COMMENT '考试id',
                                       `exam_task_detail_id` bigint DEFAULT NULL COMMENT '命题任务明细id',
                                       `exam_detail_course_id` bigint DEFAULT NULL COMMENT '考务数据课程id',
                                       `college_id` bigint NOT NULL COMMENT '学院id',
                                       `college_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '学院名称',
                                       `course_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程名称',
                                       `course_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '课程代码',
                                       `teaching_room_id` bigint NOT NULL COMMENT '教研室id',
                                       `teaching_room_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '教研室名称',
                                       `teacher_name` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '任课老师名称',
                                       `clazz_ids` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '班级ids',
                                       `clazz_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '班级名称',
                                       `paper_number` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷编号',
                                       `print_plan_id` bigint DEFAULT NULL COMMENT '印刷计划id',
                                       `batch_no` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '批次号',
                                       `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                       `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                       `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                       `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                       `data_source` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '数据来源，IMPORT：导入，JOIN：关联查询的数据',
                                       `exam_detail_id` bigint DEFAULT NULL COMMENT '命题明细id',
                                       PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='命题统计表';

-- ----------------------------
-- Table structure for t_f_custom_flow
-- ----------------------------
DROP TABLE IF EXISTS `t_f_custom_flow`;
CREATE TABLE `t_f_custom_flow` (
                                   `id` bigint NOT NULL COMMENT '主键',
                                   `school_id` bigint NOT NULL COMMENT '学校id',
                                   `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                   `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '流程名称',
                                   `model_type` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '模式类型，USER_FIXED：指定人员,APPROVE_SET：发起人指定',
                                   `type` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '流程类型，ELECTRON_FLOW：电子交卷审核，QUESTION_ELECTRON_FLOW：题库试题提交审核，PAPER_ELECTRON_FLOW：题库试卷审核',
                                   `enable` tinyint DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                   `publish` tinyint NOT NULL DEFAULT '1' COMMENT '是否发布，0：否，1：是',
                                   `object_data` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '自定义流程源数据',
                                   `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                   `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                   `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                   `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                   `version` bigint NOT NULL DEFAULT '1' COMMENT '版本号',
                                   `flow_key` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '流程key',
                                   `act_flow_id` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '流程版本id',
                                   `flow_process_var` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '流程过程变量数据',
                                   PRIMARY KEY (`id`) USING BTREE,
                                   UNIQUE KEY `custom_flow_schoolId_type_idx` (`school_id`,`type`,`enable`,`publish`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='自定义流程表';

-- ----------------------------
-- Table structure for t_f_custom_flow_entity
-- ----------------------------
DROP TABLE IF EXISTS `t_f_custom_flow_entity`;
CREATE TABLE `t_f_custom_flow_entity` (
                                          `id` bigint NOT NULL COMMENT '主键',
                                          `t_f_custom_flow_id` bigint NOT NULL COMMENT '自定义流程id',
                                          `flow_id` bigint DEFAULT NULL COMMENT '流程id',
                                          `flow_process_var` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '流程过程变量',
                                          `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                          `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                          `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                          `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                          PRIMARY KEY (`id`) USING BTREE,
                                          KEY `flow_entity_flowId_idx` (`flow_id`),
                                          KEY `flow_entity_custom_flowId_idx` (`t_f_custom_flow_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='自定义流程实体数据';

-- ----------------------------
-- Table structure for t_f_flow_approve
-- ----------------------------
DROP TABLE IF EXISTS `t_f_flow_approve`;
CREATE TABLE `t_f_flow_approve` (
                                    `id` bigint NOT NULL COMMENT '主键',
                                    `school_id` bigint NOT NULL COMMENT '学校id',
                                    `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                    `flow_id` bigint NOT NULL COMMENT '流程id',
                                    `approve_id` bigint DEFAULT NULL COMMENT '审核id',
                                    `status` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '状态，START：已开始，AUDITING：审核中，REJECT：已驳回，END：已终止，FINISH：已结束',
                                    `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                    `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                    `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                    `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                    `setup` tinyint NOT NULL COMMENT '计划步骤',
                                    `approve_setup` int DEFAULT NULL COMMENT '审批步骤',
                                    `approve_max_setup` int DEFAULT NULL COMMENT '最大审批步骤',
                                    `transfer_assignee` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '流程转办',
                                    `all_assignee` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '会签审批人',
                                    `reject_link` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '驳回路线',
                                    `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                    PRIMARY KEY (`id`) USING BTREE,
                                    KEY `flow_approve_idx` (`school_id`,`flow_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='流程审核表';

-- ----------------------------
-- Table structure for t_f_flow_join
-- ----------------------------
DROP TABLE IF EXISTS `t_f_flow_join`;
CREATE TABLE `t_f_flow_join` (
                                 `id` bigint NOT NULL COMMENT '主键',
                                 `flow_entity_id` bigint NOT NULL COMMENT '自定义流程实体id',
                                 `object_table` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '实体表',
                                 `object_id` bigint NOT NULL COMMENT '实体id',
                                 `flow_id` bigint NOT NULL COMMENT '流程id',
                                 `level` int NOT NULL COMMENT '流程等级',
                                 `type` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '类型，NEW：新增，RESTART：重新提交',
                                 `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                 `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                 PRIMARY KEY (`id`) USING BTREE,
                                 KEY `task_flowId_idx` (`flow_id`) USING BTREE,
                                 KEY `task_objectId_idx` (`object_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='实体和流程关联表';

-- ----------------------------
-- Table structure for t_f_flow_log
-- ----------------------------
DROP TABLE IF EXISTS `t_f_flow_log`;
CREATE TABLE `t_f_flow_log` (
                                `id` bigint NOT NULL COMMENT '主键',
                                `school_id` bigint NOT NULL COMMENT '学校id',
                                `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                `flow_id` bigint NOT NULL COMMENT '流程id',
                                `object_table` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '实体表',
                                `object_id` bigint NOT NULL COMMENT '实体id',
                                `approve_id` bigint DEFAULT NULL COMMENT '审核人id',
                                `approve_setup` tinyint DEFAULT NULL COMMENT '审核步骤',
                                `approve_remark` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '审核意见',
                                `enable` tinyint NOT NULL DEFAULT '1' COMMENT '是否启用，0：停用，1：启用',
                                `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                `approve_operation` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '审批操作，SUBMIT：提交，APPROVE：审批，REJECT：驳回，END：终止',
                                `pend_approve_id` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '待审核人id',
                                `paper_attachment_id` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '试卷附件',
                                `approve_multi_setup` int DEFAULT NULL COMMENT '审批步骤',
                                `approve_user_approve_type` varchar(30) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '审批用户类别，ORDER：依次审批，ALL：会签（所有人必须审批），SOME：或签（一名审批人同意或拒绝即可）',
                                PRIMARY KEY (`id`) USING BTREE,
                                KEY `flow_log_idx` (`school_id`,`flow_id`) USING BTREE,
                                KEY `flow_log_objectId_idx` (`object_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='流程流水表';

-- ----------------------------
-- Table structure for t_g_error
-- ----------------------------
DROP TABLE IF EXISTS `t_g_error`;
CREATE TABLE `t_g_error` (
                             `id` bigint NOT NULL COMMENT '主键',
                             `school_id` bigint DEFAULT NULL COMMENT '学校id',
                             `org_id` bigint DEFAULT NULL COMMENT '机构id',
                             `obj_id` bigint DEFAULT NULL COMMENT '实体id',
                             `summary` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '实时摘要信息',
                             `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                             PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='全局异常错误信息表';

-- ----------------------------
-- Table structure for t_m_mq_message
-- ----------------------------
DROP TABLE IF EXISTS `t_m_mq_message`;
CREATE TABLE `t_m_mq_message` (
                                  `id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '主键',
                                  `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                  `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                  `topic` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '消息topic',
                                  `tag` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '消息tag',
                                  `body` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '消息内容',
                                  `type` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '消息类型',
                                  `obj_id` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '关联业务id',
                                  `obj_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '关联业务名称',
                                  `ack` tinyint NOT NULL COMMENT '消息ack',
                                  `sequence` int DEFAULT NULL COMMENT '消息序号',
                                  `properties` varchar(1000) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '扩展类型',
                                  `create_time` bigint NOT NULL COMMENT '创建时间',
                                  `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                  `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                  `timestamp` bigint NOT NULL COMMENT '时间戳',
                                  `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                  PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='mq消息';

-- ----------------------------
-- Table structure for t_s_auth
-- ----------------------------
DROP TABLE IF EXISTS `t_s_auth`;
CREATE TABLE `t_s_auth` (
                            `id` bigint NOT NULL COMMENT '主键',
                            `school_id` bigint DEFAULT NULL COMMENT '学校id',
                            `access_key` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT 'accessKey',
                            `access_secret` varchar(255) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT 'accessSecret',
                            `description` text CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '离线授权证书',
                            `type` varchar(16) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '授权类型',
                            `create_id` bigint DEFAULT NULL COMMENT '创建人',
                            `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                            `update_id` bigint DEFAULT NULL COMMENT '更新人',
                            `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                            `expire_time` bigint DEFAULT NULL COMMENT '过期时间',
                            `file` mediumblob COMMENT '文件数据',
                            PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='激活授权配置表';

-- ----------------------------
-- Table structure for t_school_privilege
-- ----------------------------
DROP TABLE IF EXISTS `t_school_privilege`;
CREATE TABLE `t_school_privilege` (
                                      `id` bigint NOT NULL COMMENT '主键',
                                      `school_id` bigint NOT NULL COMMENT '学校id',
                                      `privilege_id` bigint NOT NULL COMMENT '菜单权限id',
                                      PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校菜单权限表';

-- ----------------------------
-- Table structure for t_school_role
-- ----------------------------
DROP TABLE IF EXISTS `t_school_role`;
CREATE TABLE `t_school_role` (
                                 `id` bigint NOT NULL COMMENT '主键',
                                 `school_id` bigint NOT NULL COMMENT '学校id',
                                 `role_id` bigint NOT NULL COMMENT '菜单权限id',
                                 PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='学校角色权限表';

-- ----------------------------
-- Table structure for t_sync_exam_log
-- ----------------------------
DROP TABLE IF EXISTS `t_sync_exam_log`;
CREATE TABLE `t_sync_exam_log` (
                                   `id` bigint NOT NULL,
                                   `school_id` bigint DEFAULT NULL COMMENT '学校ID',
                                   `semester_id` bigint DEFAULT NULL COMMENT '学期ID',
                                   `exam_id` bigint DEFAULT NULL COMMENT '云阅卷考试ID',
                                   `exam_name` varchar(100) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '云阅卷考试名称',
                                   `status` varchar(20) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '任务状态，INIT：未开始，RUNNING：进行中，FINISH：已完成',
                                   `result` varchar(20) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '数据结果，SUCCESS：成功，ERROR：失败',
                                   `start_time` bigint DEFAULT NULL COMMENT '同步开始时间',
                                   `end_time` bigint DEFAULT NULL COMMENT '结束同步时间',
                                   `summary` mediumtext CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci,
                                   `total_courses` int DEFAULT NULL COMMENT '总课程数',
                                   `total_exam_tasks` int DEFAULT NULL COMMENT '总命题任务数',
                                   `total_students` int DEFAULT NULL COMMENT '总考生数',
                                   `success_students` int DEFAULT NULL COMMENT '成功人数',
                                   `fail_students` int DEFAULT NULL COMMENT '失败人数',
                                   `error_file_path` varchar(500) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '错误日志文件地址',
                                   `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                   `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                   PRIMARY KEY (`id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='同步考试日志表';

-- ----------------------------
-- Table structure for t_sync_exam_student_score
-- ----------------------------
DROP TABLE IF EXISTS `t_sync_exam_student_score`;
CREATE TABLE `t_sync_exam_student_score` (
                                             `id` bigint NOT NULL COMMENT '主键',
                                             `school_id` bigint DEFAULT NULL COMMENT '学校id',
                                             `org_id` bigint DEFAULT NULL COMMENT '机构id',
                                             `semester_id` bigint DEFAULT NULL COMMENT '学期id',
                                             `major_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '专业id',
                                             `clazz_id` bigint DEFAULT NULL COMMENT '班级id',
                                             `exam_id` bigint DEFAULT NULL COMMENT '云阅卷考试id',
                                             `exam_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '云阅卷考试标识',
                                             `exam_number` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '准考证号',
                                             `student_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学号',
                                             `name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '姓名',
                                             `subject_code` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目代码',
                                             `subject_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '科目名称',
                                             `paper_type` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '试卷类型',
                                             `college` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '学院',
                                             `clazz_name` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '班级',
                                             `teacher` varchar(100) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教师',
                                             `status` tinyint DEFAULT NULL COMMENT '考生状态，1-正常，2-缺考(包含未上传)，3-违纪',
                                             `sheet_urls` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '原卷url',
                                             `local_sheet_urls` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '从云阅卷下载下来的原图url',
                                             `total_score` double DEFAULT NULL COMMENT '总分',
                                             `objective_score` double DEFAULT NULL COMMENT '客观题分数',
                                             `subjective_score` double DEFAULT NULL COMMENT '主观题分数',
                                             `sync_data` mediumtext CHARACTER SET utf8 COLLATE utf8_general_ci COMMENT '同步数据json',
                                             `trajectory_urls` varchar(500) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '轨迹图地址',
                                             `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                             `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                             PRIMARY KEY (`id`) USING BTREE,
                                             KEY `score_schoolId_idx` (`school_id`,`semester_id`,`org_id`,`major_name`,`clazz_id`,`student_code`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='同步考生成绩表';

-- ----------------------------
-- Table structure for t_sync_stmms_exam
-- ----------------------------
DROP TABLE IF EXISTS `t_sync_stmms_exam`;
CREATE TABLE `t_sync_stmms_exam` (
                                     `id` bigint NOT NULL,
                                     `school_id` bigint DEFAULT NULL COMMENT '学校ID',
                                     `exam_id` int DEFAULT NULL COMMENT '云阅卷ID',
                                     `exam_name` varchar(45) CHARACTER SET utf8mb4 COLLATE utf8mb4_general_ci DEFAULT NULL COMMENT '云阅卷考试名称',
                                     `create_id` bigint DEFAULT NULL,
                                     `create_time` bigint DEFAULT NULL,
                                     PRIMARY KEY (`id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci ROW_FORMAT=DYNAMIC COMMENT='云阅卷考试表';

-- ----------------------------
-- Table structure for teach_clazz
-- ----------------------------
DROP TABLE IF EXISTS `teach_clazz`;
CREATE TABLE `teach_clazz` (
                               `id` bigint NOT NULL COMMENT '教学班表主键',
                               `school_id` bigint NOT NULL COMMENT '学校id',
                               `teach_clazz_code` varchar(20) CHARACTER SET utf8 COLLATE utf8_general_ci DEFAULT NULL COMMENT '教学班编号',
                               `teach_clazz_name` varchar(50) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL COMMENT '教学班名称',
                               `user_id` bigint NOT NULL COMMENT '用户id',
                               `teach_course_id` bigint NOT NULL COMMENT '教学课程主键',
                               `create_id` bigint DEFAULT NULL COMMENT '创建人',
                               `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                               `update_id` bigint DEFAULT NULL COMMENT '更新人',
                               `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                               PRIMARY KEY (`id`),
                               UNIQUE KEY `teach_clazz_unique` (`school_id`,`teach_course_id`,`teach_clazz_name`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='教学班表';

-- ----------------------------
-- Table structure for teach_course
-- ----------------------------
DROP TABLE IF EXISTS `teach_course`;
CREATE TABLE `teach_course` (
                                `id` bigint NOT NULL,
                                `school_id` bigint NOT NULL COMMENT '学校id',
                                `basic_course_id` bigint NOT NULL COMMENT '基础课程id',
                                `user_id` bigint NOT NULL COMMENT '创建此教学课程的用户id',
                                `enable` tinyint(1) DEFAULT NULL COMMENT '是否删除',
                                `create_id` bigint DEFAULT NULL COMMENT '创建人id',
                                `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                `update_id` bigint DEFAULT NULL COMMENT '更新人id',
                                `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                PRIMARY KEY (`id`),
                                UNIQUE KEY `teach_course_unique` (`school_id`,`basic_course_id`,`user_id`) USING BTREE
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='教学课程表';

-- ----------------------------
-- Table structure for teach_student
-- ----------------------------
DROP TABLE IF EXISTS `teach_student`;
CREATE TABLE `teach_student` (
                                 `id` bigint NOT NULL COMMENT '教学学生关系表主键',
                                 `school_id` bigint NOT NULL COMMENT '学校id',
                                 `student_id` bigint NOT NULL COMMENT '学生id',
                                 `teach_clazz_id` bigint NOT NULL COMMENT '教学班级id',
                                 `teach_course_id` bigint NOT NULL COMMENT '教学课程id（冗余）',
                                 `user_id` bigint NOT NULL COMMENT '用户id（冗余）',
                                 `create_id` bigint DEFAULT NULL COMMENT '创建人',
                                 `create_time` bigint DEFAULT NULL COMMENT '创建时间',
                                 `update_id` bigint DEFAULT NULL COMMENT '更新人',
                                 `update_time` bigint DEFAULT NULL COMMENT '更新时间',
                                 PRIMARY KEY (`id`),
                                 UNIQUE KEY `teach_student_unique` (`school_id`,`student_id`,`teach_clazz_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci COMMENT='教学学生关系表';

-- ----------------------------
-- Function structure for getRootChildId
-- ----------------------------
delimiter //
DROP FUNCTION IF EXISTS `getRootChildId`;
CREATE FUNCTION `getRootChildId`(rootId bigint) RETURNS varchar(1000) CHARSET utf8mb4
    DETERMINISTIC
BEGIN
    DECLARE ptemp VARCHAR(1000);
    DECLARE ctemp VARCHAR(1000);
    SET ptemp = '#';
    SET ctemp = cast(rootId as CHAR);
    WHILE ctemp IS NOT NULL DO
      SET ptemp = concat(ptemp, ',', ctemp);
SELECT group_concat(id) INTO ctemp FROM sys_org WHERE FIND_IN_SET(parent_id, ctemp) > 0;
END WHILE;
RETURN ptemp;
END;
//
delimiter ;


INSERT INTO `sys_privilege` VALUES (1, '基础配置', 'base', 'MENU', NULL, 1, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (2, '用户管理', 'user', 'MENU', 1, 1, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (4, '组织架构', 'OrganizationManage', 'MENU', 2, 1, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (5, '用户管理', 'UserManage', 'MENU', 2, 2, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (6, '角色管理', 'RoleManage', 'MENU', 2, 3, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (7, '权限管理', 'MenuManage', 'MENU', 129, 6, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (77, '用户管理-查询', '/api/admin/sys/user/list', 'URL', 5, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (78, '用户管理-新增/修改', '/api/admin/sys/user/save', 'URL', 5, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (79, '用户管理-启用/禁用', '/api/admin/sys/user/enable', 'URL', 5, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (80, '用户管理-重置密码', '/api/admin/sys/user/reset_password', 'URL', 5, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (81, '用户管理-导入', '/api/admin/sys/user/import', 'URL', 5, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (82, '用户管理-绑定角色', '/api/admin/sys/user/bind_roles', 'URL', 5, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (83, '角色管理-查询', '/api/admin/sys/role/list', 'URL', 6, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (84, '角色管理-删除', '/api/admin/sys/role/remove', 'URL', 6, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (85, '角色管理-新增/修改', '/api/admin/sys/role/save', 'URL', 6, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (86, '角色管理-启用/禁用', '/api/admin/sys/role/enable', 'URL', 6, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (87, '用户管理-用户已绑定角色列表', '/api/admin/sys/role/get_user_roles', 'URL', 5, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (88, '权限管理-查询', '/api/admin/sys/privilege/list', 'URL', 7, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (89, '权限管理-新增/修改', '/api/admin/sys/privilege/save', 'URL', 7, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (90, '权限管理-删除', '/api/admin/sys/privilege/remove', 'URL', 7, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (91, '角色管理-角色已绑定权限列表', '/api/admin/sys/privilege/get_role_privileges', 'URL', 6, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (92, '组织机构-查询', '/api/admin/sys/org/list', 'URL', 4, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (93, '组织机构-新增/修改', '/api/admin/sys/org/save', 'URL', 4, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (94, '组织机构-删除', '/api/admin/sys/org/remove', 'URL', 4, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (95, '组织机构-启用/禁用', '/api/admin/sys/org/enable', 'URL', 4, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (129, '公共接口', 'common', 'MENU', NULL, 31, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (130, '用户登录相关', 'login', 'MENU', 129, 1, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (131, '用户登录', '/api/admin/common/login', 'URL', 130, 1, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (132, '查询用户权限', '/api/admin/common/get_menu', 'URL', 130, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (134, '修改密码', '/api/admin/sys/user/update_password', 'URL', 130, 4, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (135, '用户登出', '/api/admin/common/logout', 'URL', 130, 5, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (144, '文件相关', 'file', 'MENU', 129, 3, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (145, '文件上传', '/api/admin/common/file/upload', 'URL', 144, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (146, '文件查询', '/api/admin/common/file/get_one', 'URL', 144, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (147, '文件下载', '/api/admin/common/file/download', 'URL', 144, 3, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (148, '文件预览', '/api/admin/common/file/preview', 'URL', 144, 4, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (149, '系统相关', 'sys', 'MENU', 129, 4, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (151, '查询学校列表', '/api/admin/common/school/list', 'URL', 149, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (152, '查询系统参数', '/api/admin/common/sys_config/get_one', 'URL', 149, 3, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (153, '根据学校代码查询学校信息', '/api/admin/common/school/query_by_school_code', 'URL', 149, 4, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (180, '角色管理-查询可设置权限列表', '/api/admin/sys/privilege/list_auth', 'URL', 6, 6, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (184, '用户管理-查询用户可绑定角色', '/api/admin/sys/role/list_to_user', 'URL', 5, 7, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (250, '教研分析', 'report', 'MENU', NULL, 4, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (251, '学期列表', '/api/report/school/common/list_semester', 'URL', 250, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (252, '考试列表', '/api/report/school/common/list_exam', 'URL', 250, 2, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (253, '课程列表', '/api/report/school/common/list_course', 'URL', 250, 3, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (254, '开课学院列表', '/api/report/school/common/list_teach_college', 'URL', 250, 4, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (255, '考查学院列表', '/api/report/school/common/list_inspect_college', 'URL', 250, 5, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (256, '教师列表', '/api/report/school/common/list_teacher', 'URL', 250, 6, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (257, '班级列表', '/api/report/school/common/list_class', 'URL', 250, 7, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (258, '数据驾驶舱', 'cockpit', 'MENU', 250, 1, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (259, '全校考试总览', 'SchoolExam', 'MENU', 258, 1, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (260, '全校考试概况', '/api/report/school/exam/get_overview', 'URL', 259, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (261, '全校课程考试分析汇总', '/api/report/school/exam/get_course_summary', 'URL', 259, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (262, '全校课程考试分析汇总-导出课程分析Excel报表', '/api/report/school/exam/export_course_summary', 'URL', 259, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (263, '全校课程考试分析', 'SchoolCourse', 'MENU', 258, 2, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (264, '考试概况', '/api/report/school/course/get_overview', 'URL', 263, 1, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (265, '分数段分布情况', '/api/report/school/course/get_grade_distribute', 'URL', 263, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (266, '教师各课堂成绩排名', '/api/report/school/course/list_teacher_class_rank', 'URL', 263, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (267, '导出课程分析报表', '/api/report/school/course/export_data_analysis', 'URL', 263, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (268, '全校教师各课堂成绩排名', 'SchoolTeacherClassScore', 'MENU', 258, 3, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (269, '查询', '/api/report/school/teacher/list_all_teacher_class_rank', 'URL', 268, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (270, '学生', 'student', 'MENU', 250, 2, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (271, '开课成绩查询', 'TeachCollegeScore', 'MENU', 270, 1, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (272, '查询', '/api/report/school/student/list_teach_college_result', 'URL', 271, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (273, '导入异常考试类型', '/api/report/school/student/import_abnormal_data', 'URL', 271, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (274, '导出查询结果', '/api/report/school/student/export_teach_college_result', 'URL', 271, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (275, '考查成绩查询', 'InspectCollegeScore', 'MENU', 270, 2, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (276, '查询', '/api/report/school/student/list_inspect_college_result', 'URL', 275, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (277, '导出查询结果', '/api/report/school/student/export_inspect_college_result', 'URL', 275, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (278, '教师', 'teacher', 'MENU', 250, 3, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (279, '教师各课堂成绩排名', 'TeacherClassScore', 'MENU', 278, 1, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (280, '查询', '/api/report/school/teacher/list_class_rank', 'URL', 279, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (281, '我的课堂', 'MyClassScore', 'MENU', 278, 2, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (282, '查询', '/api/report/school/teacher/list_myclass_rank', 'URL', 281, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (283, '课程', 'course', 'MENU', 250, 1, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (284, '考查课程考试总览', 'InspectCourseExamOverview', 'MENU', 283, 1, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (285, '考查课程考试分析', 'InspectCourseExamAnalysis', 'MENU', 283, 2, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (286, '开课课程考试总览', 'OwnerCourseExamOverview', 'MENU', 283, 3, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (287, '开课课程考试分析', 'OwnerCourseExamAnalysis', 'MENU', 283, 4, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (288, '赋分管理', 'AssignScoreAction', 'MENU', 283, 5, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (289, '考查课程考试总览-公共课概况接口', '/api/report/course/survey_inspect/view', 'URL', 284, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (290, '考查课程考试分析-图表接口', '/api/report/course/survey_inspect_analyse/view', 'URL', 285, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (291, '开课课程考试总览-列表接口', '/api/report/course/survey_teacher/list', 'URL', 286, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (292, '开课课程考试总览-图表接口', '/api/report/course/survey_teacher/view', 'URL', 287, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (293, '赋分管理-列表接口', '/api/report/course/survey_aspoints/list', 'URL', 288, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (294, '赋分管理-开始&重新试算接口', '/api/report/course/survey_aspoints/calculation', 'URL', 288, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (295, '赋分管理-预览&查看接口', '/api/report/course/survey_aspoints/view', 'URL', 288, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (296, '赋分管理-发布&撤回接口', '/api/report/course/survey_aspoints/publish', 'URL', 288, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (297, '赋分管理-保存&保存并发布接口', '/api/report/course/survey_aspoints/save', 'URL', 288, 5, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (298, '学生报告预览', 'StudentReportManage', 'MENU', 270, 1, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (299, '学生报告预览-列表接口', '/api/report/exam_student/report/list', 'URL', 298, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (300, '学生报告-个人成绩总览接口', '/api/report/exam_student/report/result', 'URL', 298, 2, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (301, '学生报告接口', '/api/report/exam_student/report/mark', 'URL', 298, 3, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (302, '获取服务器时间', '/api/admin/common/get_system_time', 'URL', 129, 2, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (303, '开课课程考试总览-教师各课堂成绩排名接口', '/api/report/course/survey_teacher/teacher_view', 'URL', 287, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (304, '开课课程考试总览-试题难度得分情况分析接口', '/api/report/course/survey_teacher/question_view', 'URL', 287, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (305, '开课课程考试总览-各难度水平题目上的作答分析接口', '/api/report/course/survey_teacher/question_answer_view', 'URL', 287, 4, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (306, '常规配置信息导入：试卷难易度和学院排名百分等级档位', '/api/report/datasource/config/import', 'URL', 250, 100, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (307, '知识点导入模板', '/api/report/datasource/dimension/import', 'URL', 250, 101, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (308, '考试作答信息导入模板', '/api/report/datasource/examAnswer/import', 'URL', 250, 102, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (309, '模块和等级导入接口', '/api/report/datasource/moduleLevel/import', 'URL', 250, 103, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (310, '公式赋分操作', '/api/report/datasource/normal/assignScore', 'URL', 250, 104, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (311, '试卷数据导入', '/api/report/datasource/paper/import', 'URL', 250, 105, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (312, '特殊科目赋分操作', '/api/report/datasource/special/assignScore', 'URL', 250, 106, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (313, '数据计算', '/api/report/analyze/calculate', 'URL', 250, 107, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (314, '任课老师-课程列表', '/api/report/school/common/list_course_teach', 'URL', 250, 8, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (315, '开课课程考试总览-列表导出', '/api/report/course/survey_teacher/export', 'URL', 286, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (316, '考务数据同步', '/api/report/datasource/examination/sync', 'URL', 250, 109, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (317, '创建课程', '/api/report/datasource/course/create', 'URL', 250, 108, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (318, '公共实际（应届不缺考）学院查询', '/api/report/school/common/list_inspect_college_not_absent', 'URL', 250, 9, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (319, '公共实际（应届不缺考）教师查询', '/api/report/school/common/list_teacher_not_absent', 'URL', 250, 10, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (320, '导出课程分析接口', '/api/report/course/survey_teacher/course_export', 'URL', 250, 9, 'SYS', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (321, '武大学生开放鉴权接口', '/api/report/wuda/open/authentication', 'URL', 250, 11, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (322, '异常考生-批量处理', '/api/report/datasource/exception_student/batch_dispose', 'URL', 250, 110, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (323, '特殊科目合并题目处理', '/api/report/datasource/special/combine', 'URL', 250, 111, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (324, '异常答案/分数处理（先处理异常后赋分）', '/api/report/datasource/exception_answer/score_dispose', 'URL', 250, 112, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (325, '武大学生开放鉴权用户临时授权登录接口', '/api/report/wuda/open/user/authentication/login', 'URL', 250, 14, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (326, '武大学生开放鉴权测试接口', '/api/report/wuda/open/user/authentication/test', 'URL', 250, 15, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (327, '武大用户鉴权退出接口', '/api/report/wuda/open/user/authentication/logout', 'URL', 250, 16, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (328, '留学生异常处理', '/api/report/datasource/exception_student/dispose', 'URL', 250, 113, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (329, '异常考生-按学号处理', '/api/report/datasource/exception_student/dispose_by_student_code', 'URL', 250, 17, 'NO_AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (330, '我的课堂考试分析', 'MyClassExamView', 'MENU', 278, 2, NULL, NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (331, '我的课堂考试分析-图表接口', '/api/report/school/teacher/view', 'URL', 330, 1, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (332, '我的课堂考试分析-试题难度得分情况分析接口', '/api/report/school/teacher/question_view', 'URL', 330, 2, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (333, '我的课堂考试分析-各难度水平题目上的作答分析接口', '/api/report/school/teacher/question_answer_view', 'URL', 330, 3, 'AUTH', NULL, 1, 1, 1);
INSERT INTO `sys_privilege` VALUES (334, '授权配置', 'AuthManage', 'MENU', 1, 6, NULL, NULL, 1, 0, 0);
INSERT INTO `sys_privilege` VALUES (335, '授权配置-导出硬件信息按钮', 'Export', 'BUTTON', 334, 1, 'AUTH', '336,337,338', 1, 0, 0);
INSERT INTO `sys_privilege` VALUES (336, '导出硬件信息', '/api/admin/auth/export/device/info', 'URL', 335, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (337, '离线激活', '/api/admin/auth/offline/activation', 'URL', 335, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (338, '查询激活信息', '/api/admin/auth/select', 'URL', 335, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (339, '学校管理', 'SchoolManage', 'MENU', 1, 7, NULL, NULL, 1, 0, 0);
INSERT INTO `sys_privilege` VALUES (340, '查询', 'Select', 'BUTTON', 339, 1, 'AUTH', '342', 1, 0, 0);
INSERT INTO `sys_privilege` VALUES (341, '查询条件', 'Condition', 'CONDITION', 339, 2, 'AUTH', '342', 1, 0, 0);
INSERT INTO `sys_privilege` VALUES (342, '查询', '/api/admin/commom/school/list', 'URL', 339, 1, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (343, '机构同步', 'Sync', 'BUTTON', 339, 3, 'AUTH', '344', 1, 0, 0);
INSERT INTO `sys_privilege` VALUES (344, '机构同步', '/api/admin/auth/sync/org', 'URL', 339, 2, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (345, '编辑', 'Edit', 'LINK', 339, 1, 'AUTH', '346', 1, 0, 0);
INSERT INTO `sys_privilege` VALUES (346, '编辑', '/api/admin/commom/school/update', 'URL', 339, 3, 'AUTH', NULL, 1, 1, 0);
INSERT INTO `sys_privilege` VALUES (347, '同步配置保存', '/api/report/set/sync/save', 'URL', 339, 4, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (348, '同步配置查询', '/api/report/set/sync/select', 'URL', 339, 5, 'AUTH', NULL, 1, 0, 1);
INSERT INTO `sys_privilege` VALUES (349, '设置', 'Set', 'LINK', 339, 2, 'AUTH', '347,348', 1, 0, 0);
INSERT INTO `sys_privilege` VALUES (138647380756004864, '赋分即时预览', 'AssignScoreActionTry', 'MENU', 283, 6, NULL, NULL, 1, 1, 1);

INSERT INTO `sys_role` VALUES (1, NULL, '系统管理员', 1, 'ADMIN', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL);
INSERT INTO `sys_role` VALUES (2, NULL, '教务处老师', 1, 'OFFICE_TEACHER', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL);
INSERT INTO `sys_role` VALUES (3, NULL, '学院院长', 1, 'PRESIDENT', NULL, NULL, 1, 1623997638797, 1, NULL, NULL, NULL);
INSERT INTO `sys_role` VALUES (4, NULL, '任课老师', 1, 'TEACHER', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL);
INSERT INTO `sys_role` VALUES (5, NULL, '学校管理员', 1, 'SCHOOL_ADMIN', NULL, NULL, NULL, NULL, 1, NULL, NULL, NULL);

INSERT INTO `sys_role_privilege` VALUES (1, 1, 1, 1);
INSERT INTO `sys_role_privilege` VALUES (2, 1, 2, 1);
INSERT INTO `sys_role_privilege` VALUES (3, 1, 4, 1);
INSERT INTO `sys_role_privilege` VALUES (4, 1, 5, 1);
INSERT INTO `sys_role_privilege` VALUES (5, 1, 6, 1);
INSERT INTO `sys_role_privilege` VALUES (6, 1, 7, 1);
INSERT INTO `sys_role_privilege` VALUES (8, 1, 130, 1);
INSERT INTO `sys_role_privilege` VALUES (9, 1, 144, 1);
INSERT INTO `sys_role_privilege` VALUES (10, 1, 149, 1);
INSERT INTO `sys_role_privilege` VALUES (11, 1, 250, 1);
INSERT INTO `sys_role_privilege` VALUES (12, 1, 258, 1);
INSERT INTO `sys_role_privilege` VALUES (13, 1, 259, 1);
INSERT INTO `sys_role_privilege` VALUES (14, 1, 263, 1);
INSERT INTO `sys_role_privilege` VALUES (15, 1, 268, 1);
INSERT INTO `sys_role_privilege` VALUES (16, 1, 270, 1);
INSERT INTO `sys_role_privilege` VALUES (17, 1, 271, 1);
INSERT INTO `sys_role_privilege` VALUES (18, 1, 275, 1);
INSERT INTO `sys_role_privilege` VALUES (19, 1, 278, 1);
INSERT INTO `sys_role_privilege` VALUES (20, 1, 279, 1);
INSERT INTO `sys_role_privilege` VALUES (21, 1, 281, 1);
INSERT INTO `sys_role_privilege` VALUES (22, 1, 283, 1);
INSERT INTO `sys_role_privilege` VALUES (23, 1, 284, 1);
INSERT INTO `sys_role_privilege` VALUES (24, 1, 285, 1);
INSERT INTO `sys_role_privilege` VALUES (25, 1, 286, 1);
INSERT INTO `sys_role_privilege` VALUES (26, 1, 287, 1);
INSERT INTO `sys_role_privilege` VALUES (27, 1, 288, 1);
INSERT INTO `sys_role_privilege` VALUES (28, 1, 298, 1);
INSERT INTO `sys_role_privilege` VALUES (29, 1, 330, 1);
INSERT INTO `sys_role_privilege` VALUES (31, 1, 77, 1);
INSERT INTO `sys_role_privilege` VALUES (32, 1, 78, 1);
INSERT INTO `sys_role_privilege` VALUES (33, 1, 79, 1);
INSERT INTO `sys_role_privilege` VALUES (34, 1, 80, 1);
INSERT INTO `sys_role_privilege` VALUES (35, 1, 81, 1);
INSERT INTO `sys_role_privilege` VALUES (36, 1, 82, 1);
INSERT INTO `sys_role_privilege` VALUES (37, 1, 83, 1);
INSERT INTO `sys_role_privilege` VALUES (38, 1, 84, 1);
INSERT INTO `sys_role_privilege` VALUES (39, 1, 85, 1);
INSERT INTO `sys_role_privilege` VALUES (40, 1, 86, 1);
INSERT INTO `sys_role_privilege` VALUES (41, 1, 87, 1);
INSERT INTO `sys_role_privilege` VALUES (42, 1, 88, 1);
INSERT INTO `sys_role_privilege` VALUES (43, 1, 89, 1);
INSERT INTO `sys_role_privilege` VALUES (44, 1, 90, 1);
INSERT INTO `sys_role_privilege` VALUES (45, 1, 91, 1);
INSERT INTO `sys_role_privilege` VALUES (46, 1, 92, 1);
INSERT INTO `sys_role_privilege` VALUES (47, 1, 93, 1);
INSERT INTO `sys_role_privilege` VALUES (48, 1, 94, 1);
INSERT INTO `sys_role_privilege` VALUES (49, 1, 95, 1);
INSERT INTO `sys_role_privilege` VALUES (50, 1, 131, 1);
INSERT INTO `sys_role_privilege` VALUES (51, 1, 132, 1);
INSERT INTO `sys_role_privilege` VALUES (52, 1, 134, 1);
INSERT INTO `sys_role_privilege` VALUES (53, 1, 135, 1);
INSERT INTO `sys_role_privilege` VALUES (54, 1, 145, 1);
INSERT INTO `sys_role_privilege` VALUES (55, 1, 146, 1);
INSERT INTO `sys_role_privilege` VALUES (56, 1, 147, 1);
INSERT INTO `sys_role_privilege` VALUES (57, 1, 148, 1);
INSERT INTO `sys_role_privilege` VALUES (58, 1, 151, 1);
INSERT INTO `sys_role_privilege` VALUES (59, 1, 152, 1);
INSERT INTO `sys_role_privilege` VALUES (60, 1, 153, 1);
INSERT INTO `sys_role_privilege` VALUES (61, 1, 180, 1);
INSERT INTO `sys_role_privilege` VALUES (62, 1, 184, 1);
INSERT INTO `sys_role_privilege` VALUES (63, 1, 251, 1);
INSERT INTO `sys_role_privilege` VALUES (64, 1, 252, 1);
INSERT INTO `sys_role_privilege` VALUES (65, 1, 253, 1);
INSERT INTO `sys_role_privilege` VALUES (66, 1, 254, 1);
INSERT INTO `sys_role_privilege` VALUES (67, 1, 255, 1);
INSERT INTO `sys_role_privilege` VALUES (68, 1, 256, 1);
INSERT INTO `sys_role_privilege` VALUES (69, 1, 257, 1);
INSERT INTO `sys_role_privilege` VALUES (70, 1, 260, 1);
INSERT INTO `sys_role_privilege` VALUES (71, 1, 261, 1);
INSERT INTO `sys_role_privilege` VALUES (72, 1, 262, 1);
INSERT INTO `sys_role_privilege` VALUES (73, 1, 264, 1);
INSERT INTO `sys_role_privilege` VALUES (74, 1, 265, 1);
INSERT INTO `sys_role_privilege` VALUES (75, 1, 266, 1);
INSERT INTO `sys_role_privilege` VALUES (76, 1, 267, 1);
INSERT INTO `sys_role_privilege` VALUES (77, 1, 269, 1);
INSERT INTO `sys_role_privilege` VALUES (78, 1, 272, 1);
INSERT INTO `sys_role_privilege` VALUES (79, 1, 273, 1);
INSERT INTO `sys_role_privilege` VALUES (80, 1, 274, 1);
INSERT INTO `sys_role_privilege` VALUES (81, 1, 276, 1);
INSERT INTO `sys_role_privilege` VALUES (82, 1, 277, 1);
INSERT INTO `sys_role_privilege` VALUES (83, 1, 280, 1);
INSERT INTO `sys_role_privilege` VALUES (84, 1, 282, 1);
INSERT INTO `sys_role_privilege` VALUES (85, 1, 289, 1);
INSERT INTO `sys_role_privilege` VALUES (86, 1, 290, 1);
INSERT INTO `sys_role_privilege` VALUES (87, 1, 291, 1);
INSERT INTO `sys_role_privilege` VALUES (88, 1, 292, 1);
INSERT INTO `sys_role_privilege` VALUES (89, 1, 293, 1);
INSERT INTO `sys_role_privilege` VALUES (90, 1, 294, 1);
INSERT INTO `sys_role_privilege` VALUES (91, 1, 295, 1);
INSERT INTO `sys_role_privilege` VALUES (92, 1, 296, 1);
INSERT INTO `sys_role_privilege` VALUES (93, 1, 297, 1);
INSERT INTO `sys_role_privilege` VALUES (94, 1, 299, 1);
INSERT INTO `sys_role_privilege` VALUES (95, 1, 300, 1);
INSERT INTO `sys_role_privilege` VALUES (96, 1, 301, 1);
INSERT INTO `sys_role_privilege` VALUES (97, 1, 302, 1);
INSERT INTO `sys_role_privilege` VALUES (98, 1, 303, 1);
INSERT INTO `sys_role_privilege` VALUES (99, 1, 304, 1);
INSERT INTO `sys_role_privilege` VALUES (100, 1, 305, 1);
INSERT INTO `sys_role_privilege` VALUES (101, 1, 306, 1);
INSERT INTO `sys_role_privilege` VALUES (102, 1, 307, 1);
INSERT INTO `sys_role_privilege` VALUES (103, 1, 308, 1);
INSERT INTO `sys_role_privilege` VALUES (104, 1, 309, 1);
INSERT INTO `sys_role_privilege` VALUES (105, 1, 310, 1);
INSERT INTO `sys_role_privilege` VALUES (106, 1, 311, 1);
INSERT INTO `sys_role_privilege` VALUES (107, 1, 312, 1);
INSERT INTO `sys_role_privilege` VALUES (108, 1, 313, 1);
INSERT INTO `sys_role_privilege` VALUES (109, 1, 314, 1);
INSERT INTO `sys_role_privilege` VALUES (110, 1, 315, 1);
INSERT INTO `sys_role_privilege` VALUES (111, 1, 316, 1);
INSERT INTO `sys_role_privilege` VALUES (112, 1, 317, 1);
INSERT INTO `sys_role_privilege` VALUES (113, 1, 318, 1);
INSERT INTO `sys_role_privilege` VALUES (114, 1, 319, 1);
INSERT INTO `sys_role_privilege` VALUES (115, 1, 320, 1);
INSERT INTO `sys_role_privilege` VALUES (116, 1, 321, 1);
INSERT INTO `sys_role_privilege` VALUES (117, 1, 322, 1);
INSERT INTO `sys_role_privilege` VALUES (118, 1, 323, 1);
INSERT INTO `sys_role_privilege` VALUES (119, 1, 324, 1);
INSERT INTO `sys_role_privilege` VALUES (120, 1, 325, 1);
INSERT INTO `sys_role_privilege` VALUES (121, 1, 326, 1);
INSERT INTO `sys_role_privilege` VALUES (122, 1, 327, 1);
INSERT INTO `sys_role_privilege` VALUES (123, 1, 328, 1);
INSERT INTO `sys_role_privilege` VALUES (124, 1, 329, 1);
INSERT INTO `sys_role_privilege` VALUES (125, 1, 331, 1);
INSERT INTO `sys_role_privilege` VALUES (126, 1, 332, 1);
INSERT INTO `sys_role_privilege` VALUES (127, 1, 333, 1);
INSERT INTO `sys_role_privilege` VALUES (128, 1, 334, 1);
INSERT INTO `sys_role_privilege` VALUES (129, 1, 335, 1);
INSERT INTO `sys_role_privilege` VALUES (130, 1, 336, 1);
INSERT INTO `sys_role_privilege` VALUES (131, 1, 337, 1);
INSERT INTO `sys_role_privilege` VALUES (132, 1, 338, 1);
INSERT INTO `sys_role_privilege` VALUES (133, 2, 258, 1);
INSERT INTO `sys_role_privilege` VALUES (134, 2, 259, 1);
INSERT INTO `sys_role_privilege` VALUES (135, 2, 260, 1);
INSERT INTO `sys_role_privilege` VALUES (136, 2, 261, 1);
INSERT INTO `sys_role_privilege` VALUES (137, 2, 262, 1);
INSERT INTO `sys_role_privilege` VALUES (138, 2, 263, 1);
INSERT INTO `sys_role_privilege` VALUES (139, 2, 264, 1);
INSERT INTO `sys_role_privilege` VALUES (140, 2, 265, 1);
INSERT INTO `sys_role_privilege` VALUES (141, 2, 266, 1);
INSERT INTO `sys_role_privilege` VALUES (142, 2, 267, 1);
INSERT INTO `sys_role_privilege` VALUES (143, 2, 268, 1);
INSERT INTO `sys_role_privilege` VALUES (144, 2, 269, 1);
INSERT INTO `sys_role_privilege` VALUES (145, 2, 250, 1);
INSERT INTO `sys_role_privilege` VALUES (146, 5, 1, 1);
INSERT INTO `sys_role_privilege` VALUES (147, 5, 2, 1);
INSERT INTO `sys_role_privilege` VALUES (148, 5, 4, 1);
INSERT INTO `sys_role_privilege` VALUES (149, 5, 93, 1);
INSERT INTO `sys_role_privilege` VALUES (150, 5, 94, 1);
INSERT INTO `sys_role_privilege` VALUES (151, 5, 95, 1);
INSERT INTO `sys_role_privilege` VALUES (152, 5, 5, 1);
INSERT INTO `sys_role_privilege` VALUES (153, 5, 77, 1);
INSERT INTO `sys_role_privilege` VALUES (154, 5, 78, 1);
INSERT INTO `sys_role_privilege` VALUES (155, 5, 79, 1);
INSERT INTO `sys_role_privilege` VALUES (156, 5, 80, 1);
INSERT INTO `sys_role_privilege` VALUES (157, 5, 81, 1);
INSERT INTO `sys_role_privilege` VALUES (158, 5, 87, 1);
INSERT INTO `sys_role_privilege` VALUES (159, 5, 82, 1);
INSERT INTO `sys_role_privilege` VALUES (160, 5, 184, 1);
INSERT INTO `sys_role_privilege` VALUES (161, 5, 6, 1);
INSERT INTO `sys_role_privilege` VALUES (162, 5, 83, 1);
INSERT INTO `sys_role_privilege` VALUES (163, 5, 84, 1);
INSERT INTO `sys_role_privilege` VALUES (164, 5, 85, 1);
INSERT INTO `sys_role_privilege` VALUES (165, 5, 91, 1);
INSERT INTO `sys_role_privilege` VALUES (166, 5, 86, 1);
INSERT INTO `sys_role_privilege` VALUES (167, 5, 180, 1);
INSERT INTO `sys_role_privilege` VALUES (168, 5, 298, 1);
INSERT INTO `sys_role_privilege` VALUES (169, 5, 299, 1);
INSERT INTO `sys_role_privilege` VALUES (170, 5, 300, 1);
INSERT INTO `sys_role_privilege` VALUES (171, 5, 301, 1);
INSERT INTO `sys_role_privilege` VALUES (172, 5, 250, 1);
INSERT INTO `sys_role_privilege` VALUES (173, 5, 270, 1);
INSERT INTO `sys_role_privilege` VALUES (174, 3, 283, 1);
INSERT INTO `sys_role_privilege` VALUES (175, 3, 284, 1);
INSERT INTO `sys_role_privilege` VALUES (176, 3, 289, 1);
INSERT INTO `sys_role_privilege` VALUES (177, 3, 285, 1);
INSERT INTO `sys_role_privilege` VALUES (178, 3, 290, 1);
INSERT INTO `sys_role_privilege` VALUES (179, 3, 286, 1);
INSERT INTO `sys_role_privilege` VALUES (180, 3, 291, 1);
INSERT INTO `sys_role_privilege` VALUES (181, 3, 287, 1);
INSERT INTO `sys_role_privilege` VALUES (182, 3, 292, 1);
INSERT INTO `sys_role_privilege` VALUES (183, 3, 303, 1);
INSERT INTO `sys_role_privilege` VALUES (184, 3, 304, 1);
INSERT INTO `sys_role_privilege` VALUES (185, 3, 305, 1);
INSERT INTO `sys_role_privilege` VALUES (186, 3, 288, 1);
INSERT INTO `sys_role_privilege` VALUES (187, 3, 293, 1);
INSERT INTO `sys_role_privilege` VALUES (188, 3, 294, 1);
INSERT INTO `sys_role_privilege` VALUES (189, 3, 295, 1);
INSERT INTO `sys_role_privilege` VALUES (190, 3, 296, 1);
INSERT INTO `sys_role_privilege` VALUES (191, 3, 297, 1);
INSERT INTO `sys_role_privilege` VALUES (192, 3, 271, 1);
INSERT INTO `sys_role_privilege` VALUES (193, 3, 272, 1);
INSERT INTO `sys_role_privilege` VALUES (194, 3, 273, 1);
INSERT INTO `sys_role_privilege` VALUES (195, 3, 274, 1);
INSERT INTO `sys_role_privilege` VALUES (196, 3, 275, 1);
INSERT INTO `sys_role_privilege` VALUES (197, 3, 276, 1);
INSERT INTO `sys_role_privilege` VALUES (198, 3, 277, 1);
INSERT INTO `sys_role_privilege` VALUES (199, 3, 279, 1);
INSERT INTO `sys_role_privilege` VALUES (200, 3, 280, 1);
INSERT INTO `sys_role_privilege` VALUES (201, 3, 250, 1);
INSERT INTO `sys_role_privilege` VALUES (202, 3, 270, 1);
INSERT INTO `sys_role_privilege` VALUES (203, 3, 278, 1);
INSERT INTO `sys_role_privilege` VALUES (204, 3, 315, 1);
INSERT INTO `sys_role_privilege` VALUES (205, 4, 281, 1);
INSERT INTO `sys_role_privilege` VALUES (206, 4, 282, 1);
INSERT INTO `sys_role_privilege` VALUES (207, 4, 330, 1);
INSERT INTO `sys_role_privilege` VALUES (208, 4, 331, 1);
INSERT INTO `sys_role_privilege` VALUES (209, 4, 332, 1);
INSERT INTO `sys_role_privilege` VALUES (210, 4, 333, 1);
INSERT INTO `sys_role_privilege` VALUES (211, 4, 250, 1);
INSERT INTO `sys_role_privilege` VALUES (212, 4, 278, 1);

INSERT INTO `sys_user_role` VALUES (1, 1, 1, NULL, 1);

INSERT INTO `sys_config` VALUES (1, NULL, NULL, 'sys.user.initPassword', '初始密码', '123456', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (2, NULL, NULL, 'sys.warning.days', '预警天数', '3', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (3, NULL, NULL, 'sys.code.enable', '是否启用短信验证码', 'true', 'true-启用，false-禁用', 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (4, NULL, NULL, 'sys.message.enable', '是否启用短信消息提示', 'true', 'true-启用，false-禁用', 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (5, NULL, NULL, 'sys.message.resendCount', '失败短信重试次数', '3', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (9, NULL, NULL, 'admin.logo.url', '超级管理员logo', 'http://qmth-test.oss-cn-shenzhen.aliyuncs.com/frontend/wx_logo.png', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (10, NULL, NULL, 'attachment.type', '附件类型', '[.xlsx,.xls,.doc,.docx,.pdf,.jpg,.jpeg,.png,.html,.zip,.mp3,.wav,.dll,.exe,.ftl,.bpmn,.xml]', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (11, NULL, NULL, 'attachment.length', '附件名称长度', '100', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (12, NULL, NULL, 'attachment.size', '附件大小 ', '200', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (13, NULL, NULL, 'auto.create.pdf.reset.max.count', '自动重试生成pdf失败最大次数', '5', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (14, NULL, NULL, 'thread.pool.core.size', '自定义线程池大小', '1', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (15, NULL, NULL, 'custom.thread.pool.core.size', '是否自定义线程池大小', 'false', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (16, NULL, NULL, 'session.active', 'session会话时长', '2h', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (17, NULL, NULL, 'cloudmark.host.url', '云阅卷地址', 'http://192.168.10.224:80', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (18, NULL, NULL, 'sms.normal.code', '万能短信验证码', 'qmth', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (19, NULL, NULL, 'code.expired.time', '短信验证码有效时间', '2', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (20, NULL, NULL, 'code.send.interval', '短信验证码发送间隔', '60', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (21, NULL, NULL, 'teachcloud.report.student.url', '学生报告地址', 'http://localhost:9099/#/student-report/', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (22, NULL, NULL, 'teachcloud.report.login.url', '单点登录地址', 'http://localhost:8057/#/login-authen/', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (23, NULL, NULL, 'teachcloud.print.host.url', '分布式印刷地址', 'http://127.0.0.1:7400', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (24, NULL, NULL, 'teachcloud.print.open.callback.pwd', '分布式印刷回调密码', '123456', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (25, NULL, NULL, 'sms.sign.name', '短信签名', '逸教云', NULL, 1, 1, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (26, NULL, NULL, 'sms.tpl.code', '登录短信验证码', 'SMS_147416565', NULL, 1, 2, 1, NULL, NULL, NULL);
INSERT INTO `sys_config` VALUES (27, NULL, NULL, 'sys.txt.charset', 'txt文件编码', 'gbk', NULL, 1, 1, 1, NULL, NULL, NULL);